@@ -3,7 +3,7 @@
 /*
  Copyright (C) 2007 Giorgio Facchinetti
  Copyright (C) 2007 Cristina Duminuco
- Copyright (C) 2010 Ferdinando Ametrano
+ Copyright (C) 2010, 2011 Ferdinando Ametrano
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -26,6 +26,8 @@
 #include <ql/indexes/interestrateindex.hpp>
 #include <ql/termstructures/yieldtermstructure.hpp>
 
+using boost::shared_ptr;
+
 namespace QuantLib {
 
     IborCoupon::IborCoupon(const Date& paymentDate,
@@ -33,7 +35,7 @@ namespace QuantLib {
                            const Date& startDate,
                            const Date& endDate,
                            Natural fixingDays,
-                           const boost::shared_ptr<IborIndex>& iborIndex,
+                           const shared_ptr<IborIndex>& iborIndex,
                            Real gearing,
                            Spread spread,
                            const Date& refPeriodStart,
@@ -44,72 +46,75 @@ namespace QuantLib {
                          fixingDays, iborIndex, gearing, spread,
                          refPeriodStart, refPeriodEnd,
                          dayCounter, isInArrears),
-      iborIndex_(iborIndex) {}
+      iborIndex_(iborIndex) {
+
+        fixingDate_ = fixingDate();
+
+        const Calendar& fixingCalendar = index_->fixingCalendar();
+        Natural indexFixingDays = index_->fixingDays();
+
+        fixingValueDate_ = fixingCalendar.advance(
+            fixingDate_, indexFixingDays, Days);
+
+        #ifdef QL_USE_INDEXED_COUPON
+        fixingEndDate_ = index_->maturityDate(fixingValueDate_);
+        #else
+        if (isInArrears_)
+            fixingEndDate_ = index_->maturityDate(fixingValueDate_);
+        else { // par coupon approximation
+            Date nextFixingDate = fixingCalendar.advance(
+                accrualEndDate_, -static_cast<Integer>(fixingDays), Days);
+            fixingEndDate_ = fixingCalendar.advance(
+                nextFixingDate, indexFixingDays, Days);
+        }
+        #endif
+
+        const DayCounter& dc = index_->dayCounter();
+        spanningTime_ = dc.yearFraction(fixingValueDate_,
+                                        fixingEndDate_);
+        QL_REQUIRE(spanningTime_>0.0,
+                   "\n cannot calculate forward rate between " <<
+                   fixingValueDate_ << " and " << fixingEndDate_ <<
+                   ":\n non positive time (" << spanningTime_ <<
+                   ") using " << dc.name() << " daycounter");
+    }
 
     Rate IborCoupon::indexFixing() const {
 
-        #ifdef QL_USE_INDEXED_COUPON
-        return index_->fixing(fixingDate());
-        #else
-        if (isInArrears()) {
-            return index_->fixing(fixingDate());
-        } else {
-            Date today = Settings::instance().evaluationDate();
-            Date fixing_date = fixingDate();
-            if (fixing_date < today) {
-                // must have been fixed
-                Rate pastFixing = IndexManager::instance().getHistory(
-                                                 index_->name())[fixing_date];
-                QL_REQUIRE(pastFixing != Null<Real>(),
-                           "Missing " << index_->name()
-                           << " fixing for " << fixing_date);
-                return pastFixing;
-            }
-            if (fixing_date == today) {
-                // might have been fixed
-                try {
-                    Rate pastFixing = IndexManager::instance().getHistory(
-                                                 index_->name())[fixing_date];
-                    if (pastFixing != Null<Real>())
-                        return pastFixing;
-                    else
-                        ;   // fall through and forecast
-                } catch (Error&) {
-                    ;       // fall through and forecast
-                }
-            }
+        /* instead of just returning index_->fixing(fixingValueDate_)
+           its logic is duplicated here using a specialized iborIndex
+           forecastFixing overload which
+           1) allows to save date/time recalculations, and
+           2) takes into account par coupon needs
+        */
+        Date today = Settings::instance().evaluationDate();
 
-            // forecast: 0) forecasting curve
-            Handle<YieldTermStructure> termStructure =
-                iborIndex_->forwardingTermStructure();
-            QL_REQUIRE(!termStructure.empty(),
-                       "null term structure set to this instance of " <<
-                       index_->name());
+        if (fixingDate_>today)
+            return iborIndex_->forecastFixing(fixingValueDate_,
+                                              fixingEndDate_,
+                                              spanningTime_);
 
-            // forecast: 1) startDiscount
-            Date fixingValueDate = index_->fixingCalendar().advance(
-                fixing_date, index_->fixingDays(), Days);
-            DiscountFactor startDiscount =
-                termStructure->discount(fixingValueDate);
-            // forecast: 2) endDiscount
-            Date nextFixingDate = index_->fixingCalendar().advance(
-                accrualEndDate_, -static_cast<Integer>(fixingDays()), Days);
-            Date nextFixingValueDate = index_->fixingCalendar().advance(
-                nextFixingDate, index_->fixingDays(), Days);
-            DiscountFactor endDiscount =
-                termStructure->discount(nextFixingValueDate);
-            // forecast: 3) spanningTime
-            Time spanningTime = index_->dayCounter().yearFraction(
-                fixingValueDate, nextFixingValueDate);
-            QL_REQUIRE(spanningTime>0.0,
-                       "cannot calculate forward rate between " <<
-                       fixingValueDate << " and " << nextFixingValueDate <<
-                       ": non positive time using " << index_->dayCounter().name());
-            // forecast: 4) implied fixing
-            return (startDiscount/endDiscount-1.0)/spanningTime;
+        if (fixingDate_<today ||
+            Settings::instance().enforcesTodaysHistoricFixings()) {
+            // do not catch exceptions
+            Rate result = index_->pastFixing(fixingDate_);
+            QL_REQUIRE(result != Null<Real>(),
+                       "Missing " << index_->name() << " fixing for " << fixingDate_);
+            return result;
         }
-    #endif
 
+        try {
+            Rate result = index_->pastFixing(fixingDate_);
+            if (result!=Null<Real>())
+                return result;
+            else
+                ;   // fall through and forecast
+        } catch (Error&) {
+                ;   // fall through and forecast
+        }
+        return iborIndex_->forecastFixing(fixingValueDate_,
+                                          fixingEndDate_,
+                                          spanningTime_);
     }
 
     void IborCoupon::accept(AcyclicVisitor& v) {
@@ -124,7 +129,7 @@ namespace QuantLib {
 
 
     IborLeg::IborLeg(const Schedule& schedule,
-                     const boost::shared_ptr<IborIndex>& index)
+                     const shared_ptr<IborIndex>& index)
     : schedule_(schedule), index_(index),
       paymentAdjustment_(Following),
       inArrears_(false), zeroPayments_(false) {}
@@ -216,10 +221,11 @@ namespace QuantLib {
                          paymentAdjustment_, fixingDays_, gearings_, spreads_,
                          caps_, floors_, inArrears_, zeroPayments_);
 
-        if (caps_.empty() && floors_.empty() && !inArrears_)
-            setCouponPricer(leg,
-                            boost::shared_ptr<FloatingRateCouponPricer>(
-                                                  new BlackIborCouponPricer));
+        if (caps_.empty() && floors_.empty() && !inArrears_) {
+            shared_ptr<IborCouponPricer> pricer(new BlackIborCouponPricer);
+            setCouponPricer(leg, pricer);
+        }
+
         return leg;
     }
 
