@@ -2,6 +2,7 @@
 
 /*
  Copyright (C) 2008 J. Erik Radmall
+ Copyright (C) 2009 StatPro Italia srl
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -21,24 +22,34 @@
 #include <ql/experimental/commodities/petroleumunitsofmeasure.hpp>
 #include <ql/errors.hpp>
 
+using namespace std;
+
 namespace QuantLib {
 
     namespace {
 
-        struct valid_at
-            : public std::unary_function<UnitOfMeasureConversionManager::Entry,
-                                         bool> {
-            const CommodityType& commodityType;
-            const UnitOfMeasure& source, target;
-            valid_at(const CommodityType& commodityType,
-                     const UnitOfMeasure& source, const UnitOfMeasure& target) :
-            commodityType(commodityType), source(source), target(target) {}
-            bool operator()(const UnitOfMeasureConversionManager::Entry& e) {
-                return commodityType == e.conversionFactor.commodityType() &&
-                       source == e.conversionFactor.source() &&
-                       target == e.conversionFactor.target();
-            }
-        };
+        bool matches(const UnitOfMeasureConversion& c1,
+                     const UnitOfMeasureConversion& c2) {
+            return c1.commodityType() == c2.commodityType() &&
+                ((c1.source() == c2.source() && c1.target() == c2.target())
+                 || (c1.source() == c2.target() && c1.target() == c2.source()));
+        }
+
+        bool matches(const UnitOfMeasureConversion& c,
+                     const CommodityType& commodityType,
+                     const UnitOfMeasure& source,
+                     const UnitOfMeasure& target) {
+            return c.commodityType() == commodityType &&
+                ((c.source() == source && c.target() == target)
+                 || (c.source() == target && c.target() == source));
+        }
+
+        bool matches(const UnitOfMeasureConversion& c,
+                     const CommodityType& commodityType,
+                     const UnitOfMeasure& source) {
+            return c.commodityType() == commodityType &&
+                (c.source() == source || c.target() == source);
+        }
 
     }
 
@@ -47,12 +58,17 @@ namespace QuantLib {
         addKnownConversionFactors();
     }
 
-    void UnitOfMeasureConversionManager::add(
-                      const UnitOfMeasureConversion& conversionFactor) const {
-        Key k = hash(conversionFactor.commodityType(),
-                     conversionFactor.source(),
-                     conversionFactor.target());
-        data_[k].push_front(Entry(conversionFactor));
+    void UnitOfMeasureConversionManager::add(const UnitOfMeasureConversion& c) {
+        // not fast, but hopefully we won't have a lot of entries.
+        for (list<UnitOfMeasureConversion>::iterator i = data_.begin();
+             i != data_.end(); ++i) {
+            if (matches(*i, c)) {
+                data_.erase(i);
+                break;
+            }
+        }
+
+        data_.push_back(c);
     }
 
     UnitOfMeasureConversion UnitOfMeasureConversionManager::lookup(
@@ -83,164 +99,115 @@ namespace QuantLib {
         }
     }
 
-    void UnitOfMeasureConversionManager::clear() const {
+    void UnitOfMeasureConversionManager::clear() {
         data_.clear();
         addKnownConversionFactors();
     }
 
-    UnitOfMeasureConversionManager::Key
-    UnitOfMeasureConversionManager::hash(const CommodityType& commodityType,
-                                         const UnitOfMeasure& c1,
-                                         const UnitOfMeasure& c2) const {
-        return Key(string_hash(commodityType.code()) +
-                   (string_hash(c1.code()) << 2)
-                   + (string_hash(c2.code()) << 4));
-    }
-
-    void UnitOfMeasureConversionManager::addKnownConversionFactors() const {
+    void UnitOfMeasureConversionManager::addKnownConversionFactors() {
         add(UnitOfMeasureConversion(NullCommodityType(),
-                                    BarrelUnitOfMeasure(),
                                     MBUnitOfMeasure(),
+                                    BarrelUnitOfMeasure(),
                                     1000));
         add(UnitOfMeasureConversion(NullCommodityType(),
-                                    MBUnitOfMeasure(),
                                     BarrelUnitOfMeasure(),
-                                    (Real)1 / 1000));
-        add(UnitOfMeasureConversion(NullCommodityType(),
                                     GallonUnitOfMeasure(),
-                                    BarrelUnitOfMeasure(),
                                     42));
-        add(UnitOfMeasureConversion(NullCommodityType(),
-                                    BarrelUnitOfMeasure(),
-                                    GallonUnitOfMeasure(),
-                                    (Real)1 / 42));
         add(UnitOfMeasureConversion(NullCommodityType(),
                                     GallonUnitOfMeasure(),
                                     MBUnitOfMeasure(),
-                                    (Real)1 / (1000 * 42)));
+                                    1000 * 42));
         add(UnitOfMeasureConversion(NullCommodityType(),
-                                    MBUnitOfMeasure(),
-                                    GallonUnitOfMeasure(),
-                                    (1000 * 42)));
-        add(UnitOfMeasureConversion(NullCommodityType(),
-                                    GallonUnitOfMeasure(),
                                     LitreUnitOfMeasure(),
+                                    GallonUnitOfMeasure(),
                                     3.78541));
-        add(UnitOfMeasureConversion(NullCommodityType(),
-                                    LitreUnitOfMeasure(),
-                                    GallonUnitOfMeasure(),
-                                    (Real)1 / 3.78541));
         add(UnitOfMeasureConversion(NullCommodityType(),
                                     BarrelUnitOfMeasure(),
                                     LitreUnitOfMeasure(),
-                                    (Real)1 / 158.987));
-        add(UnitOfMeasureConversion(NullCommodityType(),
-                                    LitreUnitOfMeasure(),
-                                    BarrelUnitOfMeasure(),
                                     158.987));
-        add(UnitOfMeasureConversion(NullCommodityType(),
-                                    BarrelUnitOfMeasure(),
-                                    KilolitreUnitOfMeasure(),
-                                    6.28981));
         add(UnitOfMeasureConversion(NullCommodityType(),
                                     KilolitreUnitOfMeasure(),
                                     BarrelUnitOfMeasure(),
-                                    (Real)1 / 6.28981));
-        add(UnitOfMeasureConversion(NullCommodityType(),
-                                    BarrelUnitOfMeasure(),
-                                    TokyoKilolitreUnitOfMeasure(),
                                     6.28981));
         add(UnitOfMeasureConversion(NullCommodityType(),
                                     TokyoKilolitreUnitOfMeasure(),
                                     BarrelUnitOfMeasure(),
-                                    (Real)1 / 6.28981));
+                                    6.28981));
     }
 
     UnitOfMeasureConversion UnitOfMeasureConversionManager::directLookup(
                                            const CommodityType& commodityType,
                                            const UnitOfMeasure& source,
                                            const UnitOfMeasure& target) const {
-        if (const UnitOfMeasureConversion* conversionFactor =
-            fetch(commodityType,source,target))
-            return *conversionFactor;
-        else
-            QL_FAIL("no direct conversion available from "
-                    << commodityType.code() << " " << source.code()
-                    << " to " << target.code());
+
+        for (list<UnitOfMeasureConversion>::const_iterator i = data_.begin();
+             i != data_.end(); ++i) {
+            if (matches(*i, commodityType, source, target)) {
+                return *i;
+            }
+        }
+
+        // Here, the code used to look for conversions with null
+        // commodity type as a fall-back.  However, this would only
+        // affect direct lookups and not other matches being tried in
+        // the smart-lookup loop.  To implement the complete fall-back
+        // strategy, we should either duplicate the loop (as we would
+        // duplicate it here---smelly) or change the 'matches'
+        // functions so that a null commodity type matches. However,
+        // in the second case we would also have to take care that
+        // conversions with a null type be at the end of the list so
+        // that they don't supersede specific types. We'll have to
+        // think a bit about this, so no fall-back for the time being.
+
+        QL_FAIL("no direct conversion available from "
+                << commodityType.code() << " " << source.code()
+                << " to " << target.code());
     }
 
     UnitOfMeasureConversion UnitOfMeasureConversionManager::smartLookup(
                               const CommodityType& commodityType,
                               const UnitOfMeasure& source,
                               const UnitOfMeasure& target,
-                              const std::list<std::string>& forbidden) const {
-        // direct exchange conversionFactors are preferred.
-        if (const UnitOfMeasureConversion* direct =
-            fetch(commodityType,source,target))
-            return *direct;
+                              list<string> forbidden) const {
 
-#if FIXDME
-        // if none is found, turn to smart lookup. The source currency
-        // is forbidden to subsequent lookups in order to avoid cycles.
+        try {
+            return directLookup(commodityType,source,target);
+        } catch (Error&) {
+            ; // no direct conversion available; turn to smart lookup.
+        }
+
+        // The source unit is forbidden to subsequent lookups in order
+        // to avoid cycles.
         forbidden.push_back(source.code());
-        for (std::map<Key, std::list<Entry> >::const_iterator i = data_.begin();
+
+        for (list<UnitOfMeasureConversion>::const_iterator i = data_.begin();
              i != data_.end(); ++i) {
-            // we look for exchange-conversionFactor data which
-            // involve our source currency...
-            if (!(i->second.empty())) {
-                const Entry& e = i->second.front();
+            // we look for conversion data which involve our source unit...
+            if (matches(*i, commodityType, source)) {
                 const UnitOfMeasure& other =
-                    source == e.conversionFactor.source() ?
-                    e.conversionFactor.target() : e.conversionFactor.source();
-                if (std::find(forbidden.begin(),forbidden.end(),
-                              other.code()) == forbidden.end()) {
-                    if (const UnitOfMeasureConversion* head =
-                        fetch(commodityType,source,other)) {
-                        // if we can get to the target from here...
-                        try {
-                            UnitOfMeasureConversion tail =
-                                smartLookup(commodityType,other,target);
-                            // ..we're done.
-                            return UnitOfMeasureConversion::chain(*head,tail);
-                        } catch (Error&) {
-                            // otherwise, we just discard this conversionFactor.
-                            ;
-                        }
+                    source == i->source() ? i->target() : i->source();
+                if (find(forbidden.begin(),forbidden.end(),
+                         other.code()) == forbidden.end()) {
+                    // if we can get to the target from here...
+                    try {
+                        UnitOfMeasureConversion tail =
+                            smartLookup(commodityType,other,target);
+                        // ..we're done.
+                        return UnitOfMeasureConversion::chain(*i,tail);
+                    } catch (Error&) {
+                        // otherwise, we just discard this conversion.
+                        ;
                     }
                 }
             }
         }
-#endif
+
         // if the loop completed, we have no way to return the
-        // requested conversionFactor.
+        // requested conversion.
         QL_FAIL("no conversion available for "
                 << commodityType.code() << " from "
                 << source.code() << " to " << target.code());
     }
 
-    const UnitOfMeasureConversion* UnitOfMeasureConversionManager::fetch(
-                                           const CommodityType& commodityType,
-                                           const UnitOfMeasure& source,
-                                           const UnitOfMeasure& target) const {
-        const std::list<Entry>& conversionFactors =
-            data_[hash(commodityType,source,target)];
-        std::list<Entry>::const_iterator i =
-            std::find_if(conversionFactors.begin(), conversionFactors.end(),
-                         valid_at(commodityType, source, target));
-        if (i != conversionFactors.end())
-            return &(i->conversionFactor);
-
-        // if not found try to find one with a null commodity type
-        NullCommodityType nullCommodityType;
-        const std::list<Entry>& nullConversionFactors =
-            data_[hash(nullCommodityType,source,target)];
-        i = std::find_if(nullConversionFactors.begin(),
-                         nullConversionFactors.end(),
-                         valid_at(nullCommodityType, source, target));
-        if (i != nullConversionFactors.end())
-            return &(i->conversionFactor);
-        return 0;
-    }
-
 }
 
