@@ -22,10 +22,16 @@
 
 namespace QuantLib {
 
+#ifndef QL_DISABLE_DEPRECATED
     BlackVolSurface::BlackVolSurface(const Calendar& cal,
                                      BusinessDayConvention bdc,
                                      const DayCounter& dc)
     : BlackAtmVolCurve(cal, bdc, dc) {}
+#endif
+
+    BlackVolSurface::BlackVolSurface(BusinessDayConvention bdc,
+                                     const DayCounter& dc)
+    : BlackAtmVolCurve(bdc, dc) {}
 
     BlackVolSurface::BlackVolSurface(const Date& refDate,
                                      const Calendar& cal,
