@@ -3,7 +3,7 @@
 /*
  Copyright (C) 2007 Ferdinando Ametrano
  Copyright (C) 2007 Chiara Fornarola
- Copyright (C) 2005, 2006 StatPro Italia srl
+ Copyright (C) 2005, 2006, 2008 StatPro Italia srl
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -30,12 +30,10 @@
 
 namespace QuantLib {
 
-    //! base class for all BBA LIBOR indexes but the EUR ones
+    //! base class for all BBA LIBOR indexes but the EUR, O/N, and S/N ones
     /*! LIBOR fixed by BBA.
 
         See <http://www.bba.org.uk/bba/jsp/polopoly.jsp?d=225&a=1414>.
-
-        \warning This is not a valid base class for the O/N, S/N index
     */
     class Libor : public IborIndex {
       public:
@@ -45,7 +43,8 @@ namespace QuantLib {
               const Currency& currency,
               const Calendar& financialCenterCalendar,
               const DayCounter& dayCounter,
-              const Handle<YieldTermStructure>& h);
+              const Handle<YieldTermStructure>& h =
+                                    Handle<YieldTermStructure>());
         /*! \name Date calculations
 
             see http://www.bba.org.uk/bba/jsp/polopoly.jsp?d=225&a=1412
@@ -54,10 +53,32 @@ namespace QuantLib {
         Date valueDate(const Date& fixingDate) const;
         Date maturityDate(const Date& valueDate) const;
         // @}
+        //! \name Other methods
+        //@{
+        boost::shared_ptr<IborIndex> clone(
+                                   const Handle<YieldTermStructure>& h) const;
+        // @}
       private:
+        Calendar financialCenterCalendar_;
         Calendar jointCalendar_;
     };
 
+    //! base class for all O/N-S/N BBA LIBOR indexes but the EUR ones
+    /*! One day deposit LIBOR fixed by BBA.
+
+        See <http://www.bba.org.uk/bba/jsp/polopoly.jsp?d=225&a=1414>.
+    */
+    class DailyTenorLibor : public IborIndex {
+      public:
+        DailyTenorLibor(const std::string& familyName,
+                        Natural settlementDays,
+                        const Currency& currency,
+                        const Calendar& financialCenterCalendar,
+                        const DayCounter& dayCounter,
+                        const Handle<YieldTermStructure>& h =
+                                    Handle<YieldTermStructure>());
+    };
+
 }
 
 #endif
