@@ -34,25 +34,17 @@ namespace QuantLib {
       revised_(revised), interpolated_(interpolated),
       frequency_(frequency), availabilityLag_(availabilityLag),
       currency_(currency) {
+        name_ = region_.name() + " " + familyName_;
         registerWith(Settings::instance().evaluationDate());
         registerWith(IndexManager::instance().notifier(name()));
     }
 
 
-    std::string InflationIndex::name() const {
-        return region_.name() + " " + familyName_;
-    }
-
     Calendar InflationIndex::fixingCalendar() const {
         static NullCalendar c;
         return c;
     }
 
-    bool InflationIndex::isValidFixingDate(const Date&) const {
-        return true;
-    }
-
-
     void InflationIndex::addFixing(const Date& fixingDate,
                                    Real fixing,
                                    bool forceOverwrite) {
@@ -70,42 +62,6 @@ namespace QuantLib {
                           rates.begin(), forceOverwrite);
     }
 
-
-    void InflationIndex::update() {
-        notifyObservers();
-    }
-
-    std::string InflationIndex::familyName() const {
-        return familyName_;
-    }
-
-    Region InflationIndex::region() const {
-        return region_;
-    }
-
-    bool InflationIndex::revised() const {
-        return revised_;
-    }
-
-    bool InflationIndex::interpolated() const {
-        return interpolated_;
-    }
-
-    Frequency InflationIndex::frequency() const {
-        return frequency_;
-    }
-
-    Period InflationIndex::availabilityLag() const {
-        return availabilityLag_;
-    }
-
-    Currency InflationIndex::currency() const {
-        return currency_;
-    }
-
-
-
-
     ZeroInflationIndex::ZeroInflationIndex(
                       const std::string& familyName,
                       const Region& region,
@@ -123,44 +79,29 @@ namespace QuantLib {
 
     Rate ZeroInflationIndex::fixing(const Date& aFixingDate,
                                     bool /*forecastTodaysFixing*/) const {
-
-        // Stored fixings are always non-interpolated.
-        // If an interpolated fixing is required then
-        // the availability lag + one inflation period
-        // must have passsed to use historical fixings
-        // (because you need the next one to interpolate).
-        // The interpolation is calculated (linearly) on demand.
-
-        Date today = Settings::instance().evaluationDate();
-        Date todayMinusLag = today - availabilityLag_;
-
-        std::pair<Date,Date> lim = inflationPeriod(todayMinusLag, frequency_);
-        Date historicalFixingKnown = lim.first-1;
-        Date fixingDateNeeded = aFixingDate;
-        if (interpolated_) { // need the next one too
-            fixingDateNeeded = fixingDateNeeded + Period(frequency_);
-        }
-
-        if (fixingDateNeeded <= historicalFixingKnown) {
-
-            Real pastFixing =
-                IndexManager::instance().getHistory(name())[aFixingDate];
+        if (!needsForecast(aFixingDate)) {
+            const TimeSeries<Real>& ts = timeSeries();
+            Real pastFixing = ts[aFixingDate];
             QL_REQUIRE(pastFixing != Null<Real>(),
                        "Missing " << name() << " fixing for " << aFixingDate);
             Real theFixing = pastFixing;
-
             if (interpolated_) {
                 // fixings stored flat & for every day
-                Date fixingDate2 = aFixingDate + Period(frequency_);
-                Real pastFixing2 =
-                    IndexManager::instance().getHistory(name())[fixingDate2];
-                QL_REQUIRE(pastFixing2 != Null<Real>(),
-                           "Missing " << name() << " fixing for " << fixingDate2);
-                // now linearly interpolate
-                std::pair<Date,Date> lim = inflationPeriod(aFixingDate, frequency_);
-                Real daysInPeriod = lim.second+1 - lim.first;
-                theFixing = pastFixing
-                    + (pastFixing2-pastFixing)*(aFixingDate-lim.first)/daysInPeriod;
+                std::pair<Date,Date> lim =
+                    inflationPeriod(aFixingDate, frequency_);
+                if (aFixingDate == lim.first) {
+                    // we don't actually need the next fixing
+                    theFixing = pastFixing;
+                } else {
+                    Date fixingDate2 = aFixingDate + Period(frequency_);
+                    Real pastFixing2 = ts[fixingDate2];
+                    QL_REQUIRE(pastFixing2 != Null<Real>(),
+                               "Missing " << name() << " fixing for " << fixingDate2);
+                    // now linearly interpolate
+                    Real daysInPeriod = lim.second+1 - lim.first;
+                    theFixing = pastFixing
+                        + (pastFixing2-pastFixing)*(aFixingDate-lim.first)/daysInPeriod;
+                }
             }
             return theFixing;
         } else {
@@ -169,10 +110,47 @@ namespace QuantLib {
     }
 
 
-    Rate ZeroInflationIndex::forecastFixing(const Date& fixingDate) const {
+    bool ZeroInflationIndex::needsForecast(const Date& fixingDate) const {
 
+        // Stored fixings are always non-interpolated.
+        // If an interpolated fixing is required then
+        // the availability lag + one inflation period
+        // must have passed to use historical fixings
+        // (because you need the next one to interpolate).
+        // The interpolation is calculated (linearly) on demand.
+
+        Date today = Settings::instance().evaluationDate();
+        Date todayMinusLag = today - availabilityLag_;
+
+        Date historicalFixingKnown =
+            inflationPeriod(todayMinusLag, frequency_).first-1;
+        Date latestNeededDate = fixingDate;
+
+        if (interpolated_) { // might need the next one too
+            std::pair<Date,Date> p = inflationPeriod(fixingDate, frequency_);
+            if (fixingDate > p.first)
+                latestNeededDate += Period(frequency_);
+        }
+
+        if (latestNeededDate <= historicalFixingKnown) {
+            // the fixing date is well before the availability lag, so
+            // we know that fixings were provided.
+            return false;
+        } else {
+            // we're not sure, but the fixing might be there so we
+            // check.  Todo: check which fixings are not possible, to
+            // avoid using fixings in the future
+            Real f = timeSeries()[latestNeededDate];
+            return (f == Null<Real>());
+        }
+    }
+
+
+    Rate ZeroInflationIndex::forecastFixing(const Date& fixingDate) const {
         // the term structure is relative to the fixing value at the base date.
         Date baseDate = zeroInflation_->baseDate();
+        QL_REQUIRE(!needsForecast(baseDate),
+                   name() << " index fixing at base date is not available");
         Real baseFixing = fixing(baseDate);
         Date effectiveFixingDate;
         if (interpolated()) {
@@ -196,12 +174,6 @@ namespace QuantLib {
     }
 
 
-    Handle<ZeroInflationTermStructure>
-    ZeroInflationIndex::zeroInflationTermStructure() const {
-        return zeroInflation_;
-    }
-
-
     boost::shared_ptr<ZeroInflationIndex> ZeroInflationIndex::clone(
                           const Handle<ZeroInflationTermStructure>& h) const {
         return boost::shared_ptr<ZeroInflationIndex>(
@@ -251,6 +223,7 @@ namespace QuantLib {
 
         // four cases with ratio() and interpolated()
 
+        const TimeSeries<Real>& ts = timeSeries();
         if (ratio()) {
 
             if(interpolated()){ // IS ratio, IS interpolated
@@ -265,18 +238,15 @@ namespace QuantLib {
                 Real dlBef = fixMinus1Y - limBef.first;
                 // get the four relevant fixings
                 // recall that they are stored flat for every day
-                Rate limFirstFix =
-                IndexManager::instance().getHistory(name())[lim.first];
+                Rate limFirstFix = ts[lim.first];
                 QL_REQUIRE(limFirstFix != Null<Rate>(),
                             "Missing " << name() << " fixing for "
                             << lim.first );
-                Rate limSecondFix =
-                IndexManager::instance().getHistory(name())[lim.second+1];
+                Rate limSecondFix = ts[lim.second+1];
                 QL_REQUIRE(limSecondFix != Null<Rate>(),
                             "Missing " << name() << " fixing for "
                             << lim.second+1 );
-                Rate limBefFirstFix =
-                IndexManager::instance().getHistory(name())[limBef.first];
+                Rate limBefFirstFix = ts[limBef.first];
                 QL_REQUIRE(limBefFirstFix != Null<Rate>(),
                             "Missing " << name() << " fixing for "
                             << limBef.first );
@@ -293,14 +263,12 @@ namespace QuantLib {
                 return wasYES;
 
             } else {    // IS ratio, NOT interpolated
-                Rate pastFixing =
-                    IndexManager::instance().getHistory(name())[fixingDate];
+                Rate pastFixing = ts[fixingDate];
                 QL_REQUIRE(pastFixing != Null<Rate>(),
                             "Missing " << name() << " fixing for "
                             << fixingDate);
                 Date previousDate = fixingDate - 1*Years;
-                Rate previousFixing =
-                IndexManager::instance().getHistory(name())[previousDate];
+                Rate previousFixing = ts[previousDate];
                 QL_REQUIRE(previousFixing != Null<Rate>(),
                            "Missing " << name() << " fixing for "
                            << previousDate );
@@ -315,13 +283,11 @@ namespace QuantLib {
                 std::pair<Date,Date> lim = inflationPeriod(fixingDate, frequency_);
                 Real dp= lim.second + 1 - lim.first;
                 Real dl = fixingDate-lim.first;
-                Rate limFirstFix =
-                IndexManager::instance().getHistory(name())[lim.first];
+                Rate limFirstFix = ts[lim.first];
                 QL_REQUIRE(limFirstFix != Null<Rate>(),
                             "Missing " << name() << " fixing for "
                             << lim.first );
-                Rate limSecondFix =
-                IndexManager::instance().getHistory(name())[lim.second+1];
+                Rate limSecondFix = ts[lim.second+1];
                 QL_REQUIRE(limSecondFix != Null<Rate>(),
                             "Missing " << name() << " fixing for "
                             << lim.second+1 );
@@ -332,8 +298,7 @@ namespace QuantLib {
             } else { // NOT ratio, NOT interpolated
                     // so just flat
 
-                Rate pastFixing =
-                    IndexManager::instance().getHistory(name())[fixingDate];
+                Rate pastFixing = ts[fixingDate];
                 QL_REQUIRE(pastFixing != Null<Rate>(),
                            "Missing " << name() << " fixing for "
                            << fixingDate);
@@ -361,16 +326,6 @@ namespace QuantLib {
         return yoyInflation_->yoyRate(d,0*Days);
     }
 
-
-    bool YoYInflationIndex::ratio() const {
-        return ratio_;
-    }
-
-    Handle<YoYInflationTermStructure>
-    YoYInflationIndex::yoyInflationTermStructure() const {
-        return yoyInflation_;
-    }
-
     boost::shared_ptr<YoYInflationIndex> YoYInflationIndex::clone(
                            const Handle<YoYInflationTermStructure>& h) const {
         return boost::shared_ptr<YoYInflationIndex>(
@@ -380,4 +335,3 @@ namespace QuantLib {
     }
 
 }
-
