@@ -146,6 +146,10 @@ namespace QuantLib {
         return redemptions_.back();
     }
 
+    Date Bond::startDate() const {
+        return BondFunctions::startDate(*this);
+    }
+
     Date Bond::maturityDate() const {
         if (maturityDate_!=Null<Date>())
             return maturityDate_;
@@ -221,7 +225,7 @@ namespace QuantLib {
                           Compounding comp,
                           Frequency freq,
                           Date settlement) const {
-        Real currentNotional = notional(settlementDate());
+        Real currentNotional = notional(settlement);
         if (currentNotional == 0.0)
             return 0.0;
 
@@ -236,7 +240,7 @@ namespace QuantLib {
                      Date settlement,
                      Real accuracy,
                      Size maxEvaluations) const {
-        Real currentNotional = notional(settlementDate());
+        Real currentNotional = notional(settlement);
         if (currentNotional == 0.0)
             return 0.0;
 
@@ -245,7 +249,7 @@ namespace QuantLib {
     }
 
     Real Bond::accruedAmount(Date settlement) const {
-        Real currentNotional = notional(settlementDate());
+        Real currentNotional = notional(settlement);
         if (currentNotional == 0.0)
             return 0.0;
 
@@ -346,7 +350,6 @@ namespace QuantLib {
         redemptions_.push_back(redemption);
     }
 
-
     void Bond::calculateNotionalsFromCashflows() {
         notionalSchedule_.clear();
         notionals_.clear();
