@@ -83,14 +83,13 @@ namespace QuantLib {
         //@}
         Rate atmRate(const YieldTermStructure& discountCurve) const;
         //! implied term volatility
-        Volatility impliedVolatility(
-                              Real price,
-                              const Handle<YieldTermStructure>& discountCurve,
-                              Volatility guess,
-                              Real accuracy = 1.0e-4,
-                              Natural maxEvaluations = 100,
-                              Volatility minVol = 1.0e-7,
-                              Volatility maxVol = 4.0) const;
+        Volatility impliedVolatility(Real price,
+                                     const Handle<YieldTermStructure>& disc,
+                                     Volatility guess,
+                                     Real accuracy = 1.0e-4,
+                                     Natural maxEvaluations = 100,
+                                     Volatility minVol = 1.0e-7,
+                                     Volatility maxVol = 4.0) const;
       private:
         Type type_;
         Leg floatingLeg_;
