@@ -197,6 +197,9 @@ namespace QuantLib {
     inline Matrix::Matrix(const Matrix& from)
     : data_(!from.empty() ? new Real[from.rows_*from.columns_] : (Real*)(0)),
       rows_(from.rows_), columns_(from.columns_) {
+        #if defined(QL_PATCH_MSVC) && defined(QL_DEBUG)
+        if (!from.empty())
+        #endif
         std::copy(from.begin(),from.end(),begin());
     }
 
@@ -535,6 +538,9 @@ namespace QuantLib {
 
     inline const Disposable<Matrix> transpose(const Matrix& m) {
         Matrix result(m.columns(),m.rows());
+        #if defined(QL_PATCH_MSVC) && defined(QL_DEBUG)
+        if (!m.empty())
+        #endif
         for (Size i=0; i<m.rows(); i++)
             std::copy(m.row_begin(i),m.row_end(i),result.column_begin(i));
         return result;
