@@ -3,6 +3,7 @@
 /*
  Copyright (C) 2000, 2001, 2002, 2003 RiskMap srl
  Copyright (C) 2003, 2004, 2005, 2006 StatPro Italia srl
+ Copyright (C) 2011 Ferdinando Ametrano
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -26,8 +27,11 @@
 #define quantlib_observable_hpp
 
 #include <ql/errors.hpp>
+#include <ql/types.hpp>
+
 #include <boost/shared_ptr.hpp>
-#include <list>
+
+#include <set>
 
 namespace QuantLib {
 
@@ -48,10 +52,10 @@ namespace QuantLib {
         */
         void notifyObservers();
       private:
-        void registerObserver(Observer*);
-        void unregisterObserver(Observer*);
-        std::list<Observer*> observers_;
-        typedef std::list<Observer*>::iterator iterator;
+        typedef std::set<Observer*>::iterator iterator;
+        std::pair<iterator, bool> registerObserver(Observer*);
+        Size unregisterObserver(Observer*);
+        std::set<Observer*> observers_;
     };
 
     //! Object that gets notified when a given observable changes
@@ -64,8 +68,9 @@ namespace QuantLib {
         Observer& operator=(const Observer&);
         virtual ~Observer();
         // observer interface
-        void registerWith(const boost::shared_ptr<Observable>&);
-        void unregisterWith(const boost::shared_ptr<Observable>&);
+        std::pair<std::set<boost::shared_ptr<Observable> >::iterator, bool>
+                            registerWith(const boost::shared_ptr<Observable>&);
+        Size unregisterWith(const boost::shared_ptr<Observable>&);
         /*! This method must be implemented in derived classes. An
             instance of %Observer does not call this method directly:
             instead, it will be called by the observables the instance
@@ -73,15 +78,15 @@ namespace QuantLib {
         */
         virtual void update() = 0;
       private:
-        std::list<boost::shared_ptr<Observable> > observables_;
-        typedef std::list<boost::shared_ptr<Observable> >::iterator iterator;
+        std::set<boost::shared_ptr<Observable> > observables_;
+        typedef std::set<boost::shared_ptr<Observable> >::iterator iterator;
     };
 
 
     // inline definitions
 
     inline Observable::Observable(const Observable&) {
-        // the observer list is not copied; no observer asked to
+        // the observer set is not copied; no observer asked to
         // register with this object
     }
 
@@ -94,21 +99,20 @@ namespace QuantLib {
                  a later recalculation.
     */
     inline Observable& Observable::operator=(const Observable& o) {
-        // as above, the observer list is not copied. Moreover,
+        // as above, the observer set is not copied. Moreover,
         // observers of this object must be notified of the change
         if (&o != this)
             notifyObservers();
         return *this;
     }
 
-    inline void Observable::registerObserver(Observer* o) {
-        observers_.push_front(o);
+    inline std::pair<std::set<Observer*>::iterator, bool>
+    Observable::registerObserver(Observer* o) {
+        return observers_.insert(o);
     }
 
-    inline void Observable::unregisterObserver(Observer* o) {
-        iterator i = std::find(observers_.begin(),observers_.end(),o);
-        if (i != observers_.end())
-            observers_.erase(i);
+    inline Size Observable::unregisterObserver(Observer* o) {
+        return observers_.erase(o);
     }
 
     inline void Observable::notifyObservers() {
@@ -157,30 +161,22 @@ namespace QuantLib {
             (*i)->unregisterObserver(this);
     }
 
-    inline void Observer::registerWith(
-                                     const boost::shared_ptr<Observable>& h) {
+    inline std::pair<std::set<boost::shared_ptr<Observable> >::iterator, bool>
+    Observer::registerWith(const boost::shared_ptr<Observable>& h) {
         if (h) {
-            observables_.push_front(h);
             h->registerObserver(this);
+            return observables_.insert(h);
         }
+        return std::make_pair(observables_.end(), false);
     }
 
-    inline void Observer::unregisterWith(
-                                    const boost::shared_ptr<Observable>& h) {
-        if (h) {
-            for (iterator i=observables_.begin();
-                 i!=observables_.end();
-                 ++i) {
-                if (*i == h) {
-                    (*i)->unregisterObserver(this);
-                    observables_.erase(i);
-                    return;
-                }
-            }
-        }
+    inline
+    Size Observer::unregisterWith(const boost::shared_ptr<Observable>& h) {
+        if (h)
+            h->unregisterObserver(this);
+        return observables_.erase(h);
     }
 
 }
 
-
 #endif
