@@ -224,10 +224,6 @@ namespace QuantLib {
                                        + 0.5*v0_*term_;
                 }
                 else {
-                    const std::complex<Real> p = (t1-d)/(t1+d);
-                    const std::complex<Real> g
-                        = std::log((1.0 - p*ex)/(1.0 - p));
-
                     return dd_-sx_
                         - (std::exp(-kappa_*term_)*kappa_*theta_
                            +kappa_*theta_*(kappa_*term_-1.0))/(2*kappa_*kappa_)
@@ -537,9 +533,9 @@ namespace QuantLib {
             retVal = gaussianQuadrature_->operator()(
                 boost::function1<Real, Real>(
                     if_then_else_return ( (_1+1.0)*c_inf > QL_EPSILON,
-                        bind(f, -bind(std::ptr_fun<Real,Real>(std::log),
+                        boost::lambda::bind(f, -boost::lambda::bind(std::ptr_fun<Real,Real>(std::log),
                                       0.5*_1+0.5 )/c_inf )/((_1+1.0)*c_inf),
-                        bind(constant<Real, Real>(0.0), _1))));
+                        boost::lambda::bind(constant<Real, Real>(0.0), _1))));
             break;
           case Simpson:
           case Trapezoid:
@@ -548,9 +544,9 @@ namespace QuantLib {
             retVal = integrator_->operator()(
                 boost::function1<Real, Real>(
                     if_then_else_return ( _1*c_inf > QL_EPSILON,
-                        bind(f,-bind(std::ptr_fun<Real,Real>(std::log), _1)
+                        boost::lambda::bind(f,-boost::lambda::bind(std::ptr_fun<Real,Real>(std::log), _1)
                              /c_inf) /(_1*c_inf),
-                        bind(constant<Real, Real>(0.0), _1))),
+                        boost::lambda::bind(constant<Real, Real>(0.0), _1))),
                 0.0, 1.0);
             break;
           default:
