@@ -2,7 +2,7 @@
 
 /*
  Copyright (C) 2005 Joseph Wang
- Copyright (C) 2007 StatPro Italia srl
+ Copyright (C) 2007, 2009 StatPro Italia srl
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -32,8 +32,9 @@ namespace QuantLib {
 
     //! Finite-differences Bermudan engine
     /*! \ingroup vanillaengines */
+    template <template <class> class Scheme = CrankNicolson>
     class FDBermudanEngine : public VanillaOption::engine,
-                             public FDMultiPeriodEngine {
+                             public FDMultiPeriodEngine<Scheme> {
       public:
         // constructor
         FDBermudanEngine(
@@ -41,23 +42,26 @@ namespace QuantLib {
              Size timeSteps = 100,
              Size gridPoints = 100,
              bool timeDependent = false)
-        : FDMultiPeriodEngine(process, timeSteps,
-                              gridPoints, timeDependent) {}
+        : FDMultiPeriodEngine<Scheme>(process, timeSteps,
+                                      gridPoints, timeDependent) {}
         void calculate() const {
-            setupArguments(&arguments_);
-            FDMultiPeriodEngine::calculate(&results_);
+            this->setupArguments(&arguments_);
+            FDMultiPeriodEngine<Scheme>::calculate(&results_);
         }
       protected:
         Real extraTermInBermudan ;
         void initializeStepCondition() const {
-            stepCondition_ = boost::shared_ptr<StandardStepCondition>(
+            this->stepCondition_ =
+                boost::shared_ptr<StandardStepCondition>(
                                                   new NullCondition<Array>());
         };
         void executeIntermediateStep(Size ) const {
-            Size size = intrinsicValues_.size();
-            for (Size j=0; j<size; j++)
-                prices_.value(j) = std::max(prices_.value(j),
-                                            intrinsicValues_.value(j));
+            Size size = this->intrinsicValues_.size();
+            for (Size j=0; j<size; j++) {
+                this->prices_.value(j) =
+                    std::max(this->prices_.value(j),
+                             this->intrinsicValues_.value(j));
+            }
         }
     };
 
