@@ -45,7 +45,8 @@ namespace QuantLib {
     */
     class HestonProcess : public StochasticProcess {
       public:
-        enum Discretization { PartialTruncation, FullTruncation,
+        enum Discretization { PartialTruncation,
+                              FullTruncation,
                               Reflection,
                               NonCentralChiSquareVariance,
                               QuadraticExponential,
