@@ -1,7 +1,7 @@
 /* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
 /*
- Copyright (C) 2006, 2007 Ferdinando Ametrano
+ Copyright (C) 2006, 2007, 2008 Ferdinando Ametrano
  Copyright (C) 2006 Franois du Vignaud
 
  This file is part of QuantLib, a free-software/open-source library
@@ -39,8 +39,9 @@ namespace QuantLib {
                            const Handle<Quote>& forward,
                            const Handle<Quote>& price,
                            Real strike,
-                           Real guess = .15,
-                           Real accuracy = 1.0e-6);
+                           Real guess,
+                           Real accuracy = 1.0e-6,
+                           Natural maxIter = 100);
         //! \name Quote interface
         //@{
         Real value() const;
@@ -52,12 +53,11 @@ namespace QuantLib {
         Option::Type optionType_;
         Real strike_;
         Real accuracy_;
+        Natural maxIter_;
         Handle<Quote> forward_;
         Handle<Quote> price_;
     };
 
 }
 
-
 #endif
-
