@@ -1,7 +1,7 @@
 /* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
 /*
- Copyright (C) 2007 Ferdinando Ametrano
+ Copyright (C) 2007, 2011 Ferdinando Ametrano
  Copyright (C) 2007 Franois du Vignaud
  Copyright (C) 2004, 2005, 2007, 2009 StatPro Italia srl
 
@@ -71,19 +71,44 @@ namespace QuantLib {
         DateProxy& evaluationDate();
         const DateProxy& evaluationDate() const;
 
-        /*! This flag specifies whether or not cashflows occurring on
-            the NPV date should, by default, enter the NPV.  It can be
-            overridden locally when calling the NPV-related
-            methods.
+        /*! Call this to prevent the evaluation date to change at
+            midnight (and, incidentally, to gain quite a bit of
+            performance.)  If no evaluation date was previously set,
+            it is equivalent to setting the evaluation date to
+            Date::todaysDate(); if an evaluation date other than
+            Date() was already set, it has no effect.
         */
-        bool& includeReferenceDateCashFlows();
-        bool includeReferenceDateCashFlows() const;
+        void anchorEvaluationDate();
+        /*! Call this to reset the evaluation date to
+            Date::todaysDate() and allow it to change at midnight.  It
+            is equivalent to setting the evaluation date to Date().
+            This comes at the price of losing some performance, since
+            the evaluation date is re-evaluated each time it is read.
+        */
+        void resetEvaluationDate();
 
-        /*! If set, this flag specifies whether or not cashflows
+        /*! This flag specifies whether or not Events occurring on the reference
+            date should, by default, be taken into account as not happened yet.
+            It can be overridden locally when calling the Event::hasOccurred
+            method.
+        */
+        bool& includeReferenceDateEvents();
+        bool includeReferenceDateEvents() const;
+#ifndef QL_DISABLE_DEPRECATED
+        bool& includeReferenceDateCashFlows() {
+            return includeReferenceDateEvents();
+        }
+        bool includeReferenceDateCashFlows() const {
+            return includeReferenceDateEvents();
+        }
+#endif
+
+        /*! If set, this flag specifies whether or not CashFlows
             occurring on today's date should enter the NPV.  When the
             NPV date (i.e., the date at which the cash flows are
             discounted) equals today's date, this flag overrides the
-            behavior chosen for the NPV date.
+            behavior chosen for includeReferenceDate. It cannot be overridden
+            locally when calling the CashFlow::hasOccurred method.
         */
         boost::optional<bool>& includeTodaysCashFlows();
         boost::optional<bool> includeTodaysCashFlows() const;
@@ -92,7 +117,7 @@ namespace QuantLib {
         bool enforcesTodaysHistoricFixings() const;
       private:
         DateProxy evaluationDate_;
-        bool includeReferenceDateCashFlows_;
+        bool includeReferenceDateEvents_;
         boost::optional<bool> includeTodaysCashFlows_;
         bool enforcesTodaysHistoricFixings_;
     };
@@ -105,13 +130,58 @@ namespace QuantLib {
         ~SavedSettings();
       private:
         Date evaluationDate_;
-        bool includeReferenceDateCashFlows_;
+        bool includeReferenceDateEvents_;
         boost::optional<bool> includeTodaysCashFlows_;
         bool enforcesTodaysHistoricFixings_;
     };
 
+
+    // inline
+
+    inline Settings::DateProxy::operator Date() const {
+        if (value() == Date())
+            return Date::todaysDate();
+        else
+            return value();
+    }
+
+    inline Settings::DateProxy& Settings::DateProxy::operator=(const Date& d) {
+        ObservableValue<Date>::operator=(d);
+        return *this;
+    }
+
+    inline Settings::DateProxy& Settings::evaluationDate() {
+        return evaluationDate_;
+    }
+
+    inline const Settings::DateProxy& Settings::evaluationDate() const {
+        return evaluationDate_;
+    }
+
+    inline bool& Settings::includeReferenceDateEvents() {
+        return includeReferenceDateEvents_;
+    }
+
+    inline bool Settings::includeReferenceDateEvents() const {
+        return includeReferenceDateEvents_;
+    }
+
+    inline boost::optional<bool>& Settings::includeTodaysCashFlows() {
+        return includeTodaysCashFlows_;
+    }
+
+    inline boost::optional<bool> Settings::includeTodaysCashFlows() const {
+        return includeTodaysCashFlows_;
+    }
+
+    inline bool& Settings::enforcesTodaysHistoricFixings() {
+        return enforcesTodaysHistoricFixings_;
+    }
+
+    inline bool Settings::enforcesTodaysHistoricFixings() const {
+        return enforcesTodaysHistoricFixings_;
+    }
+
 }
 
-
 #endif
-
