@@ -104,10 +104,15 @@ namespace QuantLib {
         void checkRange(Time t,
                         bool extrapolate) const;
         bool moving_;
+        mutable bool updated_;
+#ifndef QL_DISABLE_DEPRECATED
         Calendar calendar_;
       private:
+#else
+      private:
+        Calendar calendar_;
+#endif
         mutable Date referenceDate_;
-        mutable bool updated_;
         Natural settlementDays_;
         DayCounter dayCounter_;
     };
