@@ -40,7 +40,7 @@ namespace QuantLib {
             constructors.
         */
         //@{
-        //! default constructor
+#ifndef QL_DISABLE_DEPRECATED
         /*! \warning term structures initialized by means of this
                      constructor must manage their own reference date
                      by overriding the referenceDate() method.
@@ -48,6 +48,13 @@ namespace QuantLib {
         CapFloorTermVolatilityStructure(const Calendar& cal,
                                         BusinessDayConvention bdc,
                                         const DayCounter& dc = DayCounter());
+#endif
+        /*! \warning term structures initialized by means of this
+                     constructor must manage their own reference date
+                     by overriding the referenceDate() method.
+        */
+        CapFloorTermVolatilityStructure(BusinessDayConvention bdc,
+                                        const DayCounter& dc = DayCounter());
         //! initialize with a fixed reference date
         CapFloorTermVolatilityStructure(const Date& referenceDate,
                                         const Calendar& cal,
