@@ -21,10 +21,16 @@
 
 namespace QuantLib {
 
+#ifndef QL_DISABLE_DEPRECATED
     LocalVolTermStructure::LocalVolTermStructure(const Calendar& cal,
                                                  BusinessDayConvention bdc,
                                                  const DayCounter& dc)
     : VolatilityTermStructure(cal, bdc, dc) {}
+#endif
+
+    LocalVolTermStructure::LocalVolTermStructure(BusinessDayConvention bdc,
+                                                 const DayCounter& dc)
+    : VolatilityTermStructure(bdc, dc) {}
 
     LocalVolTermStructure::LocalVolTermStructure(const Date& referenceDate,
                                                  const Calendar& cal,
