@@ -42,13 +42,21 @@ namespace QuantLib {
             constructors.
         */
         //@{
+#ifndef QL_DISABLE_DEPRECATED
+        /*! \warning term structures initialized by means of this
+                     constructor must manage their own reference date
+                     by overriding the referenceDate() method.
+        */
+        OptionletVolatilityStructure(const Calendar& cal,
+                                     BusinessDayConvention bdc = Following,
+                                     const DayCounter& dc = DayCounter());
+#endif
         //! default constructor
         /*! \warning term structures initialized by means of this
                      constructor must manage their own reference date
                      by overriding the referenceDate() method.
         */
-        OptionletVolatilityStructure(const Calendar& cal = Calendar(),
-                                     BusinessDayConvention bdc = Following,
+        OptionletVolatilityStructure(BusinessDayConvention bdc = Following,
                                      const DayCounter& dc = DayCounter());
         //! initialize with a fixed reference date
         OptionletVolatilityStructure(const Date& referenceDate,
