@@ -3,6 +3,7 @@
 /*
  Copyright (C) 2000, 2001, 2002, 2003 RiskMap srl
  Copyright (C) 2003, 2004 StatPro Italia srl
+ Copyright (C) 2009 Ferdinando Ametrano
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -30,12 +31,13 @@
 namespace QuantLib {
 
     //! %Forward-rate term structure
-    /*! This abstract class acts as an adapter to TermStructure allowing the
-        programmer to implement only the
-        <tt>forwardImpl(const Date&, bool)</tt> method in derived classes.
+    /*! This abstract class acts as an adapter to YieldTermStructure allowing
+        the programmer to implement only the <tt>forwardImpl(Time)</tt> method
+        in derived classes.
+
         Zero yields and discounts are calculated from forwards.
 
-        Rates are assumed to be annual continuous compounding.
+        Forward rates are assumed to be annual continuous compounding.
 
         \ingroup yieldtermstructures
     */
@@ -46,64 +48,60 @@ namespace QuantLib {
             constructors.
         */
         //@{
-        ForwardRateStructure(const DayCounter& dayCounter = Actual365Fixed());
-        ForwardRateStructure(const Date& referenceDate,
-                             const Calendar& cal = Calendar(),
-                             const DayCounter& dayCounter =Actual365Fixed());
-        ForwardRateStructure(Natural settlementDays,
-                             const Calendar&,
-                             const DayCounter& dayCounter = Actual365Fixed());
+        ForwardRateStructure(
+            const DayCounter& dayCounter = DayCounter(),
+            const std::vector<Handle<Quote> >& jumps = std::vector<Handle<Quote> >(),
+            const std::vector<Date>& jumpDates = std::vector<Date>());
+        ForwardRateStructure(
+            const Date& referenceDate,
+            const Calendar& cal = Calendar(),
+            const DayCounter& dayCounter = DayCounter(),
+            const std::vector<Handle<Quote> >& jumps = std::vector<Handle<Quote> >(),
+            const std::vector<Date>& jumpDates = std::vector<Date>());
+        ForwardRateStructure(
+            Natural settlementDays,
+            const Calendar& cal,
+            const DayCounter& dayCounter = DayCounter(),
+            const std::vector<Handle<Quote> >& jumps = std::vector<Handle<Quote> >(),
+            const std::vector<Date>& jumpDates = std::vector<Date>());
         //@}
-        virtual ~ForwardRateStructure() {}
       protected:
-        //! \name YieldTermStructure implementation
-        //@{
-        /*! Returns the discount factor for the given date calculating it
-            from the instantaneous forward rate.
+        /*! \name Calculations
+
+            These methods must be implemented in derived classes to
+            perform the actual calculations. When they are called,
+            range check has already been performed; therefore, they
+            must assume that extrapolation is required.
         */
-        DiscountFactor discountImpl(Time) const;
+        //@{
         //! instantaneous forward-rate calculation
         virtual Rate forwardImpl(Time) const = 0;
         /*! Returns the zero yield rate for the given date calculating it
-            from the instantaneous forward rate.
+            from the instantaneous forward rate \f$ f(t) \f$ as
+            \f[
+            z(t) = \int_0^t f(\tau) d\tau
+            \f]
 
-            \warning This is just a default, highly inefficient and
-                     possibly wildly inaccurate implementation. Derived
-                     classes should implement their own zeroYield method.
+            \warning This default implementation uses an highly inefficient
+                     and possibly wildly inaccurate numerical integration.
+                     Derived classes should override it if a more efficient
+                     implementation is available.
         */
         virtual Rate zeroYieldImpl(Time) const;
         //@}
+
+        //! \name YieldTermStructure implementation
+        //@{
+        /*! Returns the discount factor for the given date calculating it
+            from the zero rate as \f$ d(t) = \exp \left( -z(t) t \right) \f$
+        */
+        DiscountFactor discountImpl(Time) const;
+        //@}
     };
 
 
     // inline definitions
 
-    inline ForwardRateStructure::ForwardRateStructure(const DayCounter& dc)
-    : YieldTermStructure(dc) {}
-
-    inline ForwardRateStructure::ForwardRateStructure(const Date& refDate,
-                                                      const Calendar& cal,
-                                                      const DayCounter& dc)
-    : YieldTermStructure(refDate, cal, dc) {}
-
-    inline ForwardRateStructure::ForwardRateStructure(Natural settlDays,
-                                                      const Calendar& cal,
-                                                      const DayCounter& dc)
-    : YieldTermStructure(settlDays, cal, dc) {}
-
-    inline Rate ForwardRateStructure::zeroYieldImpl(Time t) const {
-        if (t == 0.0)
-            return forwardImpl(0.0);
-        // implement smarter integration if plan to use the following code
-        Rate sum = 0.5*forwardImpl(0.0);
-        Size N = 1000;
-        Time dt = t/N;
-        for (Time i=dt; i<t; i+=dt)
-            sum += forwardImpl(i);
-        sum += 0.5*forwardImpl(t);
-        return Rate(sum*dt/t);
-    }
-
     inline DiscountFactor ForwardRateStructure::discountImpl(Time t) const {
         if (t == 0.0)     // this acts as a safe guard in cases where
             return 1.0;   // zeroYieldImpl(0.0) would throw.
@@ -114,5 +112,4 @@ namespace QuantLib {
 
 }
 
-
 #endif
