@@ -90,21 +90,23 @@ namespace QuantLib {
                                                 bool extrapolate) const {
         checkRange(t, extrapolate);
 
-        if (!jumps_.empty()) {
-            DiscountFactor jumpEffect = 1.0;
-            for (Size i=0; i<nJumps_ && jumpTimes_[i]<t; ++i) {
+        if (jumps_.empty())
+            return discountImpl(t);
+
+        DiscountFactor jumpEffect = 1.0;
+        for (Size i=0; i<nJumps_; ++i) {
+            if (jumpTimes_[i]>0 && jumpTimes_[i]<t) {
                 QL_REQUIRE(jumps_[i]->isValid(),
                            "invalid " << io::ordinal(i+1) << " jump quote");
                 DiscountFactor thisJump = jumps_[i]->value();
-                QL_REQUIRE(thisJump > 0.0 && thisJump <= 1.0,
+                QL_REQUIRE(thisJump>0.0 && thisJump<=1.0,
                            "invalid " << io::ordinal(i+1) << " jump value: " <<
                            thisJump);
                 jumpEffect *= thisJump;
             }
-            return jumpEffect * discountImpl(t);
         }
+        return jumpEffect * discountImpl(t);
 
-        return discountImpl(t);
     }
 
     InterestRate YieldTermStructure::zeroRate(const Date& d,
