@@ -2,7 +2,7 @@
 
 /*
  Copyright (C) 2004 FIMAT Group
- Copyright (C) 2007, 2009, 2010 StatPro Italia srl
+ Copyright (C) 2007, 2009, 2010, 2011 StatPro Italia srl
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -53,6 +53,7 @@ namespace QuantLib {
             || (y == 2007 && d <= 3 && m == January)
             || (y == 2007 && d == 31 && m == December)
             || (y == 2009 && d == 2 && m == January)
+            || (y == 2011 && d == 3 && m == January)
             // Chinese New Year
             || (y == 2004 && d >= 19 && d <= 28 && m == January)
             || (y == 2005 && d >=  7 && d <= 15 && m == February)
@@ -62,28 +63,34 @@ namespace QuantLib {
             || (y == 2008 && d >= 6 && d <= 12 && m == February)
             || (y == 2009 && d >= 26 && d <= 30 && m == January)
             || (y == 2010 && d >= 15 && d <= 19 && m == January)
+            || (y == 2011 && d >= 2 && d <= 8 && m == February)
             // Ching Ming Festival
             || (y <= 2008 && d == 4 && m == April)
             || (y == 2009 && d == 6 && m == April)
             || (y == 2010 && d == 5 && m == April)
+            || (y == 2011 && d >=3 && d <= 5 && m == April)
             // Labor Day
             || (y <= 2007 && d >= 1 && d <= 7 && m == May)
             || (y == 2008 && d >= 1 && d <= 2 && m == May)
             || (y == 2009 && d == 1 && m == May)
             || (y == 2010 && d == 3 && m == May)
+            || (y == 2011 && d == 2 && m == May)
             // Tuen Ng Festival
             || (y <= 2008 && d == 9 && m == June)
             || (y == 2009 && (d == 28 || d == 29) && m == May)
             || (y == 2010 && d >= 14 && d <= 16 && m == June)
+            || (y == 2011 && d >= 4 && d <= 6 && m == June)
             // Mid-Autumn Festival
             || (y <= 2008 && d == 15 && m == September)
             || (y == 2010 && d >= 22 && d <= 24 && m == September)
+            || (y == 2011 && d >= 10 && d <= 12 && m == September)
             // National Day
             || (y <= 2007 && d >= 1 && d <= 7 && m == October)
             || (y == 2008 && ((d >= 29 && m == September) ||
                               (d <= 3 && m == October)))
             || (y == 2009 && d >= 1 && d <= 8 && m == October)
             || (y == 2010 && d >= 1 && d <= 7 && m == October)
+            || (y == 2011 && d >= 1 && d <= 7 && m == October)
             )
             return false;
         return true;
