@@ -2,8 +2,8 @@
 
 /*
  Copyright (C) 2004 FIMAT Group
- Copyright (C) 2007 StatPro Italia srl
- Copyright (C) 2008 Charles Chongseok Hyun
+ Copyright (C) 2007, 2011 StatPro Italia srl
+ Copyright (C) 2008, 2011 Charles Chongseok Hyun
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -82,12 +82,16 @@ namespace QuantLib {
             || ((d == 6 || d == 7 || d == 8) && m == February && y == 2008)
             || ((d == 25 || d == 26 || d == 27) && m == January && y == 2009)
             || ((d == 13 || d == 14 || d == 15) && m == February && y == 2010)
+            || ((d == 2 || d == 3 || d == 4) && m == February && y == 2011)
+            || ((d == 23 || d == 24) && m == January && y == 2012)
             // Election Days
             || (d == 15 && m == April && y == 2004)    // National Assembly
             || (d == 31 && m == May && y == 2006)      // Regional election
             || (d == 19 && m == December && y == 2007) // Presidency
             || (d ==  9 && m == April && y == 2008)    // National Assembly
             || (d ==  2 && m == June && y == 2010)     // Local election
+            || (d == 11 && m == April && y == 2012)    // National Assembly
+            || (d == 19 && m == December && y == 2012) // Presidency
             // Buddha's birthday
             || (d == 26 && m == May && y == 2004)
             || (d == 15 && m == May && y == 2005)
@@ -96,6 +100,8 @@ namespace QuantLib {
             || (d == 12 && m == May && y == 2008)
             || (d ==  2 && m == May && y == 2009)
             || (d == 21 && m == May && y == 2010)
+            || (d == 10 && m == May && y == 2011)
+            || (d == 28 && m == May && y == 2012)
             // Harvest Moon Day
             || ((d == 27 || d == 28 || d == 29) && m == September && y == 2004)
             || ((d == 17 || d == 18 || d == 19) && m == September && y == 2005)
@@ -104,6 +110,8 @@ namespace QuantLib {
             || ((d == 13 || d == 14 || d == 15) && m == September && y == 2008)
             || ((d ==  2 || d ==  3 || d ==  4) && m == October && y == 2009)
             || ((d == 21 || d == 22 || d == 23) && m == September && y == 2010)
+            || ((d == 12 || d == 13) && m == September && y == 2011)
+            || (d == 1 && m == October && y == 2012)
             )
             return false;
 
@@ -127,6 +135,8 @@ namespace QuantLib {
             || (d == 31 && m == December && y == 2008)
             || (d == 31 && m == December && y == 2009)
             || (d == 31 && m == December && y == 2010)
+            || (d == 30 && m == December && y == 2011)
+            || (d == 31 && m == December && y == 2012)
             )
             return false;
 
