@@ -4,7 +4,7 @@
  Copyright (C) 2004, 2005, 2006 Ferdinando Ametrano
  Copyright (C) 2006 Katiuscia Manzoni
  Copyright (C) 2000, 2001, 2002, 2003 RiskMap srl
- Copyright (C) 2003, 2004, 2005, 2006 StatPro Italia srl
+ Copyright (C) 2003, 2004, 2005, 2006, 2008 StatPro Italia srl
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -42,9 +42,11 @@ namespace QuantLib {
                      Quarterly = 4,        //!< every third month
                      Bimonthly = 6,        //!< every second month
                      Monthly = 12,         //!< once a month
+                     EveryFourthWeek = 13, //!< every fourth week
                      Biweekly = 26,        //!< every second week
                      Weekly = 52,          //!< once a week
-                     Daily = 365           //!< once a day
+                     Daily = 365,          //!< once a day
+                     OtherFrequency = 999  //!< some other unknown frequency
     };
 
     /*! \relates Frequency */
