@@ -1,9 +1,9 @@
 /* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
 /*
- Copyright (C) 2006, 2007, 2008, 2010 Ferdinando Ametrano
+ Copyright (C) 2006, 2007, 2008, 2010, 2011 Ferdinando Ametrano
  Copyright (C) 2000, 2001, 2002, 2003 RiskMap srl
- Copyright (C) 2009 StatPro Italia srl
+ Copyright (C) 2009, 2012 StatPro Italia srl
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -69,7 +69,6 @@ namespace QuantLib {
       convention_(convention),
       terminationDateConvention_(convention),
       rule_(DateGeneration::Forward), endOfMonth_(false),
-      finalIsRegular_(true),
       dates_(dates) {}
 
     Schedule::Schedule(Date effectiveDate,
@@ -88,8 +87,7 @@ namespace QuantLib {
       terminationDateConvention_(terminationDateConvention),
       rule_(rule), endOfMonth_(endOfMonth),
       firstDate_(first==effectiveDate ? Date() : first),
-      nextToLastDate_(nextToLast==terminationDate ? Date() : nextToLast),
-      finalIsRegular_(true)
+      nextToLastDate_(nextToLast==terminationDate ? Date() : nextToLast)
     {
         // sanity checks
         QL_REQUIRE(terminationDate != Date(), "null termination date");
@@ -225,8 +223,13 @@ namespace QuantLib {
                     }
                     break;
                 } else {
-                    dates_.insert(dates_.begin(), temp);
-                    isRegular_.insert(isRegular_.begin(), true);
+                    // skip dates that would result in duplicates
+                    // after adjustment
+                    if (calendar_.adjust(dates_.front(),convention)!=
+                        calendar_.adjust(temp,convention)) {
+                        dates_.insert(dates_.begin(), temp);
+                        isRegular_.insert(isRegular_.begin(), true);
+                    }
                     ++periods;
                 }
             }
@@ -303,8 +306,13 @@ namespace QuantLib {
                     }
                     break;
                 } else {
-                    dates_.push_back(temp);
-                    isRegular_.push_back(true);
+                    // skip dates that would result in duplicates
+                    // after adjustment
+                    if (calendar_.adjust(dates_.back(),convention)!=
+                        calendar_.adjust(temp,convention)) {
+                        dates_.push_back(temp);
+                        isRegular_.push_back(true);
+                    }
                     ++periods;
                 }
             }
@@ -345,9 +353,7 @@ namespace QuantLib {
                 for (Size i=0; i<dates_.size()-1; ++i)
                     dates_[i] = calendar_.endOfMonth(dates_[i]);
             }
-            if (terminationDateConvention == Unadjusted)
-                dates_.back() = Date::endOfMonth(dates_.back());
-            else
+            if (terminationDateConvention != Unadjusted)
                 dates_.back() = calendar_.endOfMonth(dates_.back());
         } else {
             // first date not adjusted for CDS schedules
@@ -379,6 +385,35 @@ namespace QuantLib {
 
     }
 
+
+    Schedule Schedule::until(const Date& truncationDate) const {
+        Schedule result = *this;
+
+        if (truncationDate<result.dates_.back()) {
+            // remove later dates
+            while (result.dates_.back()>truncationDate) {
+                result.dates_.pop_back();
+                result.isRegular_.pop_back();
+            }
+
+            // add truncationDate if missing
+            if (truncationDate!=result.dates_.back()) {
+                result.dates_.push_back(truncationDate);
+                result.isRegular_.push_back(false);
+                result.terminationDateConvention_ = Unadjusted;
+            } else {
+                result.terminationDateConvention_ = convention_;
+            }
+
+            if (result.nextToLastDate_>=truncationDate)
+                result.nextToLastDate_ = Date();
+            if (result.firstDate_>=truncationDate)
+                result.firstDate_ = Date();
+        }
+
+        return result;
+    }
+
     std::vector<Date>::const_iterator
     Schedule::lower_bound(const Date& refDate) const {
         Date d = (refDate==Date() ?
