@@ -33,7 +33,7 @@
 #include <ql/pricingengines/vanilla/jumpdiffusionengine.hpp>
 #include <ql/pricingengines/vanilla/analyticeuropeanengine.hpp>
 #include <ql/pricingengines/vanilla/mceuropeanhestonengine.hpp>
-#include <ql/experimental/finitedifferences/fdbatesvanillaengine.hpp>
+#include <ql/pricingengines/vanilla/fdbatesvanillaengine.hpp>
 #include <ql/models/equity/batesmodel.hpp>
 #include <ql/models/equity/hestonmodelhelper.hpp>
 #include <ql/time/period.hpp>
@@ -368,9 +368,9 @@ void BatesModelTest::testAnalyticVsMCPricing() {
         const Real fdTolerance = 0.2;
         const Real fdError = std::fabs(fdCalculated - expected);
         if (fdError > fdTolerance) {
-            BOOST_FAIL("failed to PIDE price for BatesEngine"
+            BOOST_FAIL("failed to reproduce PIDE price for BatesEngine"
                        << QL_FIXED << std::setprecision(8)
-                       << "\n    calculated: " << calculated
+                       << "\n    calculated: " << fdCalculated
                        << "\n    expected:   " << expected
                        << "\n    error: "      << fdError
                        << "\n    tolerance:  " << fdTolerance);
