@@ -3,7 +3,7 @@
 /*
  Copyright (C) 2004, 2005 StatPro Italia srl
  Copyright (C) 2007 Ferdinando Ametrano
- Copyright (C) 2007 Piter Dias
+ Copyright (C) 2007, 2009 Piter Dias
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -41,6 +41,7 @@
 #include <ql/cashflows/couponpricer.hpp>
 #include <ql/cashflows/cashflows.hpp>
 #include <ql/pricingengines/bond/discountingbondengine.hpp>
+#include <ql/pricingengines/bond/bondfunctions.hpp>
 
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
@@ -97,14 +98,15 @@ void BondTest::testYield() {
             for (Size n=0; n<LENGTH(compounding); n++) {
 
               Date dated = vars.calendar.advance(vars.today,
-                                                    issueMonths[i], Months);
+                                                 issueMonths[i], Months);
               Date issue = dated;
               Date maturity = vars.calendar.advance(issue,
-                                                       lengths[j], Years);
+                                                    lengths[j], Years);
 
               Schedule sch(dated, maturity,
                            Period(frequencies[l]), vars.calendar,
-                           accrualConvention, accrualConvention, DateGeneration::Backward, false);
+                           accrualConvention, accrualConvention,
+                           DateGeneration::Backward, false);
 
               FixedRateBond bond(settlementDays, vars.faceAmount, sch,
                                  std::vector<Rate>(1, coupons[k]),
@@ -113,10 +115,11 @@ void BondTest::testYield() {
 
               for (Size m=0; m<LENGTH(yields); m++) {
 
-                Real price = bond.cleanPrice(yields[m],
-                                             bondDayCount, compounding[n],
-                                             frequencies[l]);
-                Rate calculated = bond.yield(price,
+                Real price = BondFunctions::cleanPrice(bond, yields[m],
+                                                 bondDayCount,
+                                                 compounding[n],
+                                                 frequencies[l]);
+                Rate calculated = BondFunctions::yield(bond, price,
                                              bondDayCount, compounding[n],
                                              frequencies[l],
                                              Date(),
@@ -124,23 +127,116 @@ void BondTest::testYield() {
 
                 if (std::fabs(yields[m]-calculated) > tolerance) {
                   // the difference might not matter
-                  Real price2 = bond.cleanPrice(calculated,
-                                                bondDayCount, compounding[n],
-                                                frequencies[l]);
+                  Real price2 = BondFunctions::cleanPrice(bond, calculated,
+                                                    bondDayCount,
+                                                    compounding[n],
+                                                    frequencies[l]);
                   if (std::fabs(price-price2)/price > tolerance) {
-                      BOOST_ERROR(
-                          "yield recalculation failed:\n"
-                          << "    issue:     " << issue << "\n"
-                          << "    maturity:  " << maturity << "\n"
-                          << "    coupon:    " << io::rate(coupons[k]) << "\n"
-                          << "    frequency: " << frequencies[l] << "\n\n"
-                          << "    yield:  " << io::rate(yields[m]) << " "
-                          << (compounding[n] == Compounded ?
-                              "compounded" : "continuous") << "\n"
-                          << std::setprecision(7)
-                          << "    price:  " << price << "\n"
-                          << "    yield': " << io::rate(calculated) << "\n"
-                          << "    price': " << price2);
+                      BOOST_FAIL("\nyield recalculation failed:"
+                          "\n    issue:     " << issue <<
+                          "\n    maturity:  " << maturity <<
+                          "\n    coupon:    " << io::rate(coupons[k]) <<
+                          "\n    frequency: " << frequencies[l] <<
+                          "\n    yield:   " << io::rate(yields[m]) <<
+                          (compounding[n] == Compounded ?
+                                " compounded" : " continuous") <<
+                          std::setprecision(7) <<
+                          "\n    price:   " << price <<
+                          "\n    yield': " << io::rate(calculated) <<
+                          "\n    price': " << price2);
+                  }
+                }
+              }
+            }
+          }
+        }
+      }
+    }
+}
+
+void BondTest::testZspread() {
+
+    BOOST_MESSAGE("Testing consistency of bond price/z-spread calculation...");
+
+    CommonVars vars;
+
+    Real tolerance = 1.0e-7;
+    Size maxEvaluations = 100;
+
+    Handle<YieldTermStructure> discountCurve(
+                                       flatRate(vars.today,0.03,Actual360()));
+
+    Integer issueMonths[] = { -24, -18, -12, -6, 0, 6, 12, 18, 24 };
+    Integer lengths[] = { 3, 5, 10, 15, 20 };
+    Natural settlementDays = 3;
+    Real coupons[] = { 0.02, 0.05, 0.08 };
+    Frequency frequencies[] = { Semiannual, Annual };
+    DayCounter bondDayCount = Thirty360();
+    BusinessDayConvention accrualConvention = Unadjusted;
+    BusinessDayConvention paymentConvention = ModifiedFollowing;
+    Real redemption = 100.0;
+
+    Spread spreads[] = { -0.01, -0.005, 0.0, 0.005, 0.01 };
+    Compounding compounding[] = { Compounded, Continuous };
+
+    for (Size i=0; i<LENGTH(issueMonths); i++) {
+      for (Size j=0; j<LENGTH(lengths); j++) {
+        for (Size k=0; k<LENGTH(coupons); k++) {
+          for (Size l=0; l<LENGTH(frequencies); l++) {
+            for (Size n=0; n<LENGTH(compounding); n++) {
+
+              Date dated = vars.calendar.advance(vars.today,
+                                                 issueMonths[i], Months);
+              Date issue = dated;
+              Date maturity = vars.calendar.advance(issue,
+                                                    lengths[j], Years);
+
+              Schedule sch(dated, maturity,
+                           Period(frequencies[l]), vars.calendar,
+                           accrualConvention, accrualConvention,
+                           DateGeneration::Backward, false);
+
+              FixedRateBond bond(settlementDays, vars.faceAmount, sch,
+                                 std::vector<Rate>(1, coupons[k]),
+                                 bondDayCount, paymentConvention,
+                                 redemption, issue);
+
+              for (Size m=0; m<LENGTH(spreads); m++) {
+
+                Real price = BondFunctions::cleanPrice(bond, *discountCurve,
+                                                   spreads[m],
+                                                   bondDayCount,
+                                                   compounding[n],
+                                                   frequencies[l]);
+                Spread calculated = BondFunctions::zSpread(bond, price,
+                                                           *discountCurve,
+                                                           bondDayCount,
+                                                           compounding[n],
+                                                           frequencies[l],
+                                                           Date(),
+                                                           tolerance,
+                                                           maxEvaluations);
+
+                if (std::fabs(spreads[m]-calculated) > tolerance) {
+                  // the difference might not matter
+                  Real price2 = BondFunctions::cleanPrice(bond, *discountCurve,
+                                                      calculated,
+                                                      bondDayCount,
+                                                      compounding[n],
+                                                      frequencies[l]);
+                  if (std::fabs(price-price2)/price > tolerance) {
+                      BOOST_FAIL("\nZ-spread recalculation failed:"
+                          "\n    issue:     " << issue <<
+                          "\n    maturity:  " << maturity <<
+                          "\n    coupon:    " << io::rate(coupons[k]) <<
+                          "\n    frequency: " << frequencies[l] <<
+                          "\n    Z-spread:  " << io::rate(spreads[m]) <<
+                          (compounding[n] == Compounded ?
+                                " compounded" : " continuous") <<
+                          std::setprecision(7) <<
+                          "\n    price:     " << price <<
+                          "\n    Z-spread': " << io::rate(calculated) <<
+                          "\n    price':    " << price2);
                   }
                 }
               }
@@ -204,39 +300,38 @@ void BondTest::testTheoretical() {
 
                 rate->setValue(yields[m]);
 
-                Real price = bond.cleanPrice(yields[m],
-                                             bondDayCount, Continuous,
-                                             frequencies[l]);
+                Real price = BondFunctions::cleanPrice(bond, yields[m],
+                                                 bondDayCount, Continuous,
+                                                 frequencies[l]);
                 Real calculatedPrice = bond.cleanPrice();
 
                 if (std::fabs(price-calculatedPrice) > tolerance) {
-                    BOOST_FAIL(
-                        "price calculation failed:"
-                        << "\n    issue:     " << issue
-                        << "\n    maturity:  " << maturity
-                        << "\n    coupon:    " << io::rate(coupons[k])
-                        << "\n    frequency: " << frequencies[l] << "\n"
-                        << "\n    yield:  " << io::rate(yields[m])
-                        << std::setprecision(7)
-                        << "\n    expected:    " << price
-                        << "\n    calculated': " << calculatedPrice
-                        << "\n    error':      " << price-calculatedPrice);
+                    BOOST_FAIL("price calculation failed:" <<
+                        "\n    issue:     " << issue <<
+                        "\n    maturity:  " << maturity <<
+                        "\n    coupon:    " << io::rate(coupons[k]) <<
+                        "\n    frequency: " << frequencies[l] <<
+                        "\n    yield:  " << io::rate(yields[m]) <<
+                        std::setprecision(7) <<
+                        "\n    expected:    " << price <<
+                        "\n    calculated': " << calculatedPrice <<
+                        "\n    error':      " << price-calculatedPrice);
                 }
 
-                Rate calculatedYield = bond.yield(
+                Rate calculatedYield = BondFunctions::yield(bond, calculatedPrice,
                     bondDayCount, Continuous, frequencies[l],
+                    bond.settlementDate(),
                     tolerance, maxEvaluations);
                 if (std::fabs(yields[m]-calculatedYield) > tolerance) {
-                    BOOST_FAIL(
-                        "yield calculation failed:"
-                        << "\n    issue:     " << issue
-                        << "\n    maturity:  " << maturity
-                        << "\n    coupon:    " << io::rate(coupons[k])
-                        << "\n    frequency: " << frequencies[l] << "\n"
-                        << "\n    yield:  " << io::rate(yields[m])
-                        << std::setprecision(7)
-                        << "\n    price:  " << price
-                        << "\n    yield': " << io::rate(calculatedYield));
+                    BOOST_FAIL("yield calculation failed:" <<
+                        "\n    issue:     " << issue <<
+                        "\n    maturity:  " << maturity <<
+                        "\n    coupon:    " << io::rate(coupons[k]) <<
+                        "\n    frequency: " << frequencies[l] <<
+                        "\n    yield:  " << io::rate(yields[m]) <<
+                        std::setprecision(7) <<
+                        "\n    price:  " << price <<
+                        "\n    yield': " << io::rate(calculatedYield));
                 }
             }
         }
@@ -308,7 +403,7 @@ void BondTest::testCached() {
     Real tolerance = 1.0e-6;
     Real price, yield;
 
-    price = bond1.cleanPrice(marketYield1,
+    price = BondFunctions::cleanPrice(bond1, marketYield1,
                              bondDayCount, Compounded, freq);
     if (std::fabs(price-cachedPrice1a) > tolerance) {
         BOOST_FAIL("failed to reproduce cached price:"
@@ -329,17 +424,17 @@ void BondTest::testCached() {
                    << "\n    error:      " << price-cachedPrice1b);
     }
 
-    yield = bond1.yield(marketPrice1, bondDayCount, Compounded, freq);
+    yield = BondFunctions::yield(bond1, marketPrice1, bondDayCount, Compounded, freq);
     if (std::fabs(yield-cachedYield1a) > tolerance) {
-        BOOST_FAIL("failed to reproduce cached compounded yield:"
-                   << std::setprecision(4)
-                   << "\n    calculated: " << io::rate(yield)
-                   << "\n    expected:   " << io::rate(cachedYield1a)
-                   << "\n    tolerance:  " << io::rate(tolerance)
-                   << "\n    error:      " << io::rate(yield-cachedYield1a));
+        BOOST_FAIL("\nfailed to reproduce cached compounded yield:" <<
+                   std::setprecision(4) <<
+                   "\n    calculated: " << io::rate(yield) <<
+                   "\n    expected:   " << io::rate(cachedYield1a) <<
+                   "\n    tolerance:  " << io::rate(tolerance) <<
+                   "\n    error:      " << io::rate(yield-cachedYield1a));
     }
 
-    yield = bond1.yield(marketPrice1, bondDayCount, Continuous, freq);
+    yield = BondFunctions::yield(bond1, marketPrice1, bondDayCount, Continuous, freq);
     if (std::fabs(yield-cachedYield1b) > tolerance) {
         BOOST_FAIL("failed to reproduce cached continuous yield:"
                    << std::setprecision(4)
@@ -349,7 +444,7 @@ void BondTest::testCached() {
                    << "\n    error:      " << io::rate(yield-cachedYield1b));
     }
 
-    yield = bond1.yield(bondDayCount, Continuous, freq);
+    yield = BondFunctions::yield(bond1, bond1.cleanPrice(), bondDayCount, Continuous, freq, bond1.settlementDate());
     if (std::fabs(yield-cachedYield1c) > tolerance) {
         BOOST_FAIL("failed to reproduce cached continuous yield:"
                    << std::setprecision(4)
@@ -360,7 +455,7 @@ void BondTest::testCached() {
     }
 
 
-    price = bond2.cleanPrice(marketYield2, bondDayCount, Compounded, freq);
+    price = BondFunctions::cleanPrice(bond2, marketYield2, bondDayCount, Compounded, freq);
     if (std::fabs(price-cachedPrice2a) > tolerance) {
         BOOST_FAIL("failed to reproduce cached price:"
                    << QL_FIXED
@@ -380,7 +475,7 @@ void BondTest::testCached() {
                    << "\n    error:      " << price-cachedPrice2b);
     }
 
-    yield = bond2.yield(marketPrice2, bondDayCount, Compounded, freq);
+    yield = BondFunctions::yield(bond2, marketPrice2, bondDayCount, Compounded, freq);
     if (std::fabs(yield-cachedYield2a) > tolerance) {
         BOOST_FAIL("failed to reproduce cached compounded yield:"
                    << std::setprecision(4)
@@ -390,7 +485,7 @@ void BondTest::testCached() {
                    << "\n    error:      " << io::rate(yield-cachedYield2a));
     }
 
-    yield = bond2.yield(marketPrice2, bondDayCount, Continuous, freq);
+    yield = BondFunctions::yield(bond2, marketPrice2, bondDayCount, Continuous, freq);
     if (std::fabs(yield-cachedYield2b) > tolerance) {
         BOOST_FAIL("failed to reproduce cached continuous yield:"
                    << std::setprecision(4)
@@ -400,7 +495,7 @@ void BondTest::testCached() {
                    << "\n    error:      " << io::rate(yield-cachedYield2b));
     }
 
-    yield = bond2.yield(bondDayCount, Continuous, freq);
+    yield = BondFunctions::yield(bond2, bond2.cleanPrice(), bondDayCount, Continuous, freq, bond2.settlementDate());
     if (std::fabs(yield-cachedYield2c) > tolerance) {
         BOOST_FAIL("failed to reproduce cached continuous yield:"
                    << std::setprecision(4)
@@ -430,7 +525,7 @@ void BondTest::testCached() {
     Date settlementDate = Date(30,November,2004);
     Real cachedPrice3 = 99.764874;
 
-    price = bond3.cleanPrice(marketYield3,
+    price = BondFunctions::cleanPrice(bond3, marketYield3,
                              bondDayCount, Compounded, freq, settlementDate);
     if (std::fabs(price-cachedPrice3) > tolerance) {
         BOOST_FAIL("failed to reproduce cached price:"
@@ -445,7 +540,7 @@ void BondTest::testCached() {
 
     Settings::instance().evaluationDate() = Date(22,November,2004);
 
-    price = bond3.cleanPrice(marketYield3, bondDayCount, Compounded, freq);
+    price = BondFunctions::cleanPrice(bond3, marketYield3, bondDayCount, Compounded, freq);
     if (std::fabs(price-cachedPrice3) > tolerance) {
         BOOST_FAIL("failed to reproduce cached price:"
                    << QL_FIXED
@@ -767,11 +862,20 @@ void BondTest::testCachedFloating() {
 void BondTest::testBrazilianCached() {
 
     BOOST_MESSAGE(
-        "Testing Brazilian public bond prices against cached values...");
+        "Testing Brazilian public bond prices against Andima cached values...");
 
     CommonVars vars;
 
+    Natural settlementDays = 1;
+    Real faceAmount = 1000.0;
+    Real redemption = 100.0;
     Date today(6,June,2007);
+    Date issueDate(1,January,2007);
+
+    // The tolerance is high because Andima truncate yields
+    Real tolerance = 1.0e-4;
+
+    // Reset evaluation date
     Settings::instance().evaluationDate() = today;
 
     // NTN-F maturity dates
@@ -783,7 +887,7 @@ void BondTest::testBrazilianCached() {
     maturityDates[4] = Date(1,January,2014);
     maturityDates[5] = Date(1,January,2017);
 
-    // NTN-F yields
+    // Andima NTN-F yields
     std::vector<Rate> yields(6);
     yields[0] = 0.114614;
     yields[1] = 0.105726;
@@ -792,7 +896,7 @@ void BondTest::testBrazilianCached() {
     yields[4] = 0.103218;
     yields[5] = 0.102948;
 
-    // NTN-F prices
+    // Andima NTN-F prices
     std::vector<Rate> prices(6);
     prices[0] = 1034.63031372;
     prices[1] = 1030.09919487;
@@ -801,18 +905,11 @@ void BondTest::testBrazilianCached() {
     prices[4] = 1028.33383817;
     prices[5] = 1026.19716497;
 
-    Natural settlementDays = 1;
-    vars.faceAmount = 1000.0;
-
-    // The tolerance is high because Andima truncate yields
-    Real tolerance = 1.0e-4;
-
     std::vector<InterestRate> couponRates(1);
-    couponRates[0] = InterestRate(0.1,Thirty360(),Compounded,Annual);
+    couponRates[0] = InterestRate(0.1, Thirty360(), Compounded,Annual);
 
     for (Size bondIndex = 0; bondIndex < maturityDates.size(); bondIndex++) {
 
-        // plain
         InterestRate yield(yields[bondIndex],
                            Business252(Brazil()),
                            Compounded, Annual);
@@ -823,29 +920,22 @@ void BondTest::testBrazilianCached() {
                           Unadjusted, Unadjusted,
                           DateGeneration::Backward, false);
 
-        // fixed coupons
-        Leg cashflows =
-            FixedRateLeg(schedule, Actual360())
-            .withNotionals(vars.faceAmount)
-            .withCouponRates(couponRates)
-            .withPaymentAdjustment(ModifiedFollowing);
-        // redemption
-        cashflows.push_back(boost::shared_ptr<CashFlow>(
-              new SimpleCashFlow(vars.faceAmount, cashflows.back()->date())));
-
-        Bond bond(settlementDays, Brazil(Brazil::Settlement),
-                  vars.faceAmount, cashflows.back()->date(),
-                  Date(1,January,2007), cashflows);
+        FixedRateBond bond(settlementDays,
+            faceAmount,
+            schedule,
+            couponRates,
+            Following,
+            redemption,
+            issueDate);
 
         Real cachedPrice = prices[bondIndex];
+        Real price = faceAmount *
+            (BondFunctions::cleanPrice(bond, yield.rate(), yield.dayCounter(),
+                                 yield.compounding(), yield.frequency(),
+                                 today) + bond.accruedAmount(today)) / 100.0;
 
-        Real price = vars.faceAmount*bond.dirtyPrice(yield.rate(),
-                                                     yield.dayCounter(),
-                                                     yield.compounding(),
-                                                     yield.frequency(),
-                                                     today)/100;
         if (std::fabs(price-cachedPrice) > tolerance) {
-            BOOST_ERROR("failed to reproduce cached price:\n"
+            BOOST_ERROR("failed to reproduce Andima cached price:\n"
                         << QL_FIXED
                         << "    calculated: " << price << "\n"
                         << "    expected:   " << cachedPrice << "\n"
@@ -861,6 +951,7 @@ test_suite* BondTest::suite() {
     test_suite* suite = BOOST_TEST_SUITE("Bond tests");
 
     suite->add(QUANTLIB_TEST_CASE(&BondTest::testYield));
+    suite->add(QUANTLIB_TEST_CASE(&BondTest::testZspread));
     suite->add(QUANTLIB_TEST_CASE(&BondTest::testTheoretical));
     suite->add(QUANTLIB_TEST_CASE(&BondTest::testCached));
     suite->add(QUANTLIB_TEST_CASE(&BondTest::testCachedZero));
