@@ -35,6 +35,7 @@
 #include <ql/utilities/dataformatters.hpp>
 #include <ql/cashflows/cashflows.hpp>
 #include <ql/cashflows/couponpricer.hpp>
+#include <ql/quotes/simplequote.hpp>
 
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
@@ -90,9 +91,9 @@ namespace {
                               convention, convention,
                               DateGeneration::Forward, false);
             std::vector<Rate> coupons(length, 0.0);
-            return FixedRateLeg(schedule, Thirty360())
+            return FixedRateLeg(schedule)
                 .withNotionals(nominals)
-                .withCouponRates(coupons);
+                .withCouponRates(coupons, Thirty360());
         }
 
         Leg makeFloatingLeg(const Date& startDate,
