@@ -27,18 +27,18 @@
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
 
-QL_BEGIN_TEST_LOCALS(CovarianceTest)
+namespace {
+
+    Real norm(const Matrix& m) {
+        Real sum = 0.0;
+        for (Size i=0; i<m.rows(); i++)
+            for (Size j=0; j<m.columns(); j++)
+                sum += m[i][j]*m[i][j];
+        return std::sqrt(sum);
+    }
 
-Real norm(const Matrix& m) {
-    Real sum = 0.0;
-    for (Size i=0; i<m.rows(); i++)
-        for (Size j=0; j<m.columns(); j++)
-            sum += m[i][j]*m[i][j];
-    return std::sqrt(sum);
 }
 
-QL_END_TEST_LOCALS(CovarianceTest)
-
 
 void CovarianceTest::testRankReduction() {
 
@@ -268,9 +268,9 @@ void CovarianceTest::testCovariance() {
 
 test_suite* CovarianceTest::suite() {
     test_suite* suite = BOOST_TEST_SUITE("Covariance/correlation tests");
-    suite->add(BOOST_TEST_CASE(&CovarianceTest::testCovariance));
-    suite->add(BOOST_TEST_CASE(&CovarianceTest::testSalvagingMatrix));
-    suite->add(BOOST_TEST_CASE(&CovarianceTest::testRankReduction));
+    suite->add(QUANTLIB_TEST_CASE(&CovarianceTest::testCovariance));
+    suite->add(QUANTLIB_TEST_CASE(&CovarianceTest::testSalvagingMatrix));
+    suite->add(QUANTLIB_TEST_CASE(&CovarianceTest::testRankReduction));
     return suite;
 }
 
