@@ -303,7 +303,9 @@ void CreditDefaultSwapTest::testImpliedHazardRate() {
     SavedSettings backup;
 
     // Initialize curves
-    Date today = Settings::instance().evaluationDate();
+    Calendar calendar = TARGET();
+    Date today = calendar.adjust(Date::todaysDate());
+    Settings::instance().evaluationDate() = today;
 
     Rate h1 = 0.30, h2 = 0.40;
     DayCounter dayCounter = Actual365Fixed();
@@ -330,7 +332,6 @@ void CreditDefaultSwapTest::testImpliedHazardRate() {
                             new FlatForward(today,0.03,Actual360())));
 
 
-    Calendar calendar = TARGET();
     Frequency frequency = Semiannual;
     BusinessDayConvention convention = ModifiedFollowing;
 
@@ -528,6 +529,27 @@ void CreditDefaultSwapTest::testFairUpfront() {
     Real fairNPV = fairCds.NPV();
     Real tolerance = 1e-10;
 
+    if (std::fabs(fairNPV) > tolerance)
+        BOOST_ERROR(
+            "Failed to reproduce null NPV with calculated fair upfront\n"
+            << "    calculated upfront: " << io::rate(fairUpfront) << "\n"
+            << "    calculated NPV:     " << fairNPV);
+
+    // same with null upfront to begin with
+    upfront = 0.0;
+    CreditDefaultSwap cds2(Protection::Seller, notional, upfront, fixedRate,
+                           schedule, convention, dayCount, true, true);
+    cds2.setPricingEngine(engine);
+
+    fairUpfront = cds2.fairUpfront();
+
+    CreditDefaultSwap fairCds2(Protection::Seller, notional,
+                               fairUpfront, fixedRate,
+                               schedule, convention, dayCount, true, true);
+    fairCds2.setPricingEngine(engine);
+
+    fairNPV = fairCds2.NPV();
+
     if (std::fabs(fairNPV) > tolerance)
         BOOST_ERROR(
             "Failed to reproduce null NPV with calculated fair upfront\n"
