@@ -2,6 +2,7 @@
 
 /*
  Copyright (C) 2006 Klaus Spanderen
+ Copyright (C) 2010 Slava Mazur
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -23,6 +24,7 @@
 #include <ql/math/randomnumbers/rngtraits.hpp>
 #include <ql/math/linearleastsquaresregression.hpp>
 #include <boost/bind.hpp>
+#include <boost/circular_buffer.hpp>
 
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
@@ -50,9 +52,9 @@ void LinearLeastSquaresRegressionTest::testRegression() {
     for (Size k=0; k<3; ++k) {
         Size i;
         const Real a[] = {rng.next().value,
-                          rng.next().value,
-                          rng.next().value,
-                          rng.next().value};
+            rng.next().value,
+            rng.next().value,
+            rng.next().value};
 
         std::vector<Real> x(nr), y(nr);
         for (i=0; i<nr; ++i) {
@@ -60,47 +62,47 @@ void LinearLeastSquaresRegressionTest::testRegression() {
 
             // regression in y = a_1 + a_2*x + a_3*x^2 + a_4*sin(x) + eps
             y[i] =  a[0]*v[0](x[i]) + a[1]*v[1](x[i]) + a[2]*v[2](x[i])
-                  + a[3]*v[3](x[i]) + rng.next().value;
+                + a[3]*v[3](x[i]) + rng.next().value;
         }
 
-        LinearLeastSquaresRegression<> m(x, y, v);
+        LinearRegression m(x, y, v);
 
         for (i=0; i<v.size(); ++i) {
             if (m.standardErrors()[i] > tolerance) {
                 BOOST_ERROR("Failed to reproduce linear regression coef."
-                            << "\n    error:     " << m.standardErrors()[i]
-                            << "\n    tolerance: " << tolerance);
+                    << "\n    error:     " << m.standardErrors()[i]
+                << "\n    tolerance: " << tolerance);
             }
             if (std::fabs(m.coefficients()[i]-a[i]) > 3*m.standardErrors()[i]) {
                 BOOST_ERROR("Failed to reproduce linear regression coef."
-                            << "\n    calculated: " << m.coefficients()[i]
-                            << "\n    error:      " << m.standardErrors()[i]
-                            << "\n    expected:   " << a[i]);
+                    << "\n    calculated: " << m.coefficients()[i]
+                << "\n    error:      " << m.standardErrors()[i]
+                << "\n    expected:   " << a[i]);
             }
         }
 
-        m = LinearLeastSquaresRegression<>(x, y, w);
+        m = LinearRegression(x, y, w);
 
         const Real ma[] = {m.coefficients()[0], m.coefficients()[1], 
-                           m.coefficients()[2]+m.coefficients()[4],
-                           m.coefficients()[3]};
+            m.coefficients()[2]+m.coefficients()[4],
+            m.coefficients()[3]};
         const Real err[] = {m.standardErrors()[0], m.standardErrors()[1],
-                        std::sqrt( m.standardErrors()[2]*m.standardErrors()[2]
-                                  +m.standardErrors()[4]*m.standardErrors()[4]),
-                            m.standardErrors()[3]};
+            std::sqrt( m.standardErrors()[2]*m.standardErrors()[2]
+        +m.standardErrors()[4]*m.standardErrors()[4]),
+            m.standardErrors()[3]};
         for (i=0; i<v.size(); ++i) {
             if (std::fabs(ma[i] - a[i]) > 3*err[i]) {
                 BOOST_ERROR("Failed to reproduce linear regression coef."
-                            << "\n    calculated: " << ma[i]
-                            << "\n    error:      " << err[i]
-                            << "\n    expected:   " << a[i]);
+                    << "\n    calculated: " << ma[i]
+                << "\n    error:      " << err[i]
+                << "\n    expected:   " << a[i]);
             }
         }
     }
 }
 
 namespace {
-    Real f(const std::vector<Real>& a, Size i) {
+    Real f(const Array& a, Size i) {
         return a[i];
     }
 }
@@ -116,8 +118,8 @@ void LinearLeastSquaresRegressionTest::testMultiDimRegression() {
     const Real tolerance = 0.01;
     PseudoRandom::rng_type rng(PseudoRandom::urng_type(1234u));
 
-    std::vector<boost::function1<Real, std::vector<Real> > > v;
-    v.push_back(constant<std::vector<Real>, Real>(1.0));
+    std::vector<boost::function1<Real, Array> > v;
+    v.push_back(constant<Array, Real>(1.0));
     for (Size i=0; i < dims; ++i) {
         v.push_back(boost::bind(f, _1, i));
     }
@@ -126,41 +128,52 @@ void LinearLeastSquaresRegressionTest::testMultiDimRegression() {
     for (Size i=0; i < v.size(); ++i) {
         coeff[i] = rng.next().value;
     }
-    
+
     std::vector<Real> y(nr, 0.0);
-    std::vector<std::vector<Real> > x(nr, std::vector<Real>(dims));
+    std::vector<Array> x(nr, Array(dims));
     for (Size i=0; i < nr; ++i) {
         for (Size j=0; j < dims; ++j) {
             x[i][j] = rng.next().value;
         }
-        
+
         for (Size j=0; j < v.size(); ++j) {
             y[i] += coeff[j]*v[j](x[i]);
         }
         y[i] += rng.next().value;
     }
-    
-    LinearRegression reg(x,y);
-    LinearLeastSquaresRegression<std::vector<Real> > m(x, y, v);
-    
+
+    LinearRegression m(x, y, v);
+
     for (Size i=0; i < v.size(); ++i) {
         if (m.standardErrors()[i] > tolerance) {
             BOOST_ERROR("Failed to reproduce linear regression coef."
-                        << "\n    error:     " << m.standardErrors()[i]
-                        << "\n    tolerance: " << tolerance);
+                << "\n    error:     " << m.standardErrors()[i]
+            << "\n    tolerance: " << tolerance);
         }
-        
+
         if (std::fabs(m.coefficients()[i]-coeff[i]) > 3*tolerance) {
             BOOST_ERROR("Failed to reproduce linear regression coef."
-                        << "\n    calculated: " << m.coefficients()[i]
-                        << "\n    error:      " << m.standardErrors()[i]
-                        << "\n    expected:   " << coeff[i]);
+                << "\n    calculated: " << m.coefficients()[i]
+            << "\n    error:      " << m.standardErrors()[i]
+            << "\n    expected:   " << coeff[i]);
         }
-        if (std::fabs(reg.coefficients()[i]-coeff[i]) > 3*tolerance) {
+    }
+
+    // much simpler
+    LinearRegression m1(x, y, 1.0);
+
+    for (Size i=0; i < m1.dim(); ++i) {
+        if (m1.standardErrors()[i] > tolerance) {
             BOOST_ERROR("Failed to reproduce linear regression coef."
-                        << "\n    calculated: " << m.coefficients()[i]
-                        << "\n    error:      " << m.standardErrors()[i]
-                        << "\n    expected:   " << coeff[i]);
+                << "\n    error:     " << m1.standardErrors()[i]
+            << "\n    tolerance: " << tolerance);
+        }
+
+        if (std::fabs(m1.coefficients()[i]-coeff[i]) > 3*tolerance) {
+            BOOST_ERROR("Failed to reproduce linear regression coef."
+                << "\n    calculated: " << m1.coefficients()[i]
+            << "\n    error:      " << m1.standardErrors()[i]
+            << "\n    expected:   " << coeff[i]);
         }
     }
 }
@@ -170,10 +183,10 @@ void LinearLeastSquaresRegressionTest::test1dLinearRegression() {
     BOOST_MESSAGE("Testing 1D simple linear least-squares regression...");
 
     /* Example taken from the QuantLib-User list, see posting
-     * Multiple linear regression/weighted regression, Boris Skorodumov */
-    
+    * Multiple linear regression/weighted regression, Boris Skorodumov */
+
     SavedSettings backup;
-    
+
     std::vector<Real> x(9),y(9);
     x[0]=2.4; x[1]=1.8; x[2]=2.5; x[3]=3.0; 
     x[4]=2.1; x[5]=1.2; x[6]=2.0; x[7]=2.7; x[8]=3.6;
@@ -186,7 +199,7 @@ void LinearLeastSquaresRegressionTest::test1dLinearRegression() {
     v.push_back(identity<Real>());
 
     LinearRegression m(x, y);
-    
+
     const Real tol = 0.0002;
     const Real coeffExpected[]  = { 0.9448, 2.6853 };
     const Real errorsExpected[] = { 0.3654, 0.1487 };
@@ -194,16 +207,36 @@ void LinearLeastSquaresRegressionTest::test1dLinearRegression() {
     for (Size i=0; i < 2; ++i) {
         if (std::fabs(m.standardErrors()[i]-errorsExpected[i]) > tol) {
             BOOST_ERROR("Failed to reproduce linear regression standard errors"
-                        << "\n    calculated: " << m.standardErrors()[i]
-                        << "\n    expected:   " << errorsExpected[i]                                          
-                        << "\n    tolerance:  " << tol);
+                << "\n    calculated: " << m.standardErrors()[i]
+            << "\n    expected:   " << errorsExpected[i]                                          
+            << "\n    tolerance:  " << tol);
         }
-        
+
         if (std::fabs(m.coefficients()[i]-coeffExpected[i]) > tol) {
             BOOST_ERROR("Failed to reproduce linear regression coef."
-                        << "\n    calculated: " << m.coefficients()[i]
-                        << "\n    expected:   " << coeffExpected[i]
-                        << "\n    tolerance:  " << tol);
+                << "\n    calculated: " << m.coefficients()[i]
+            << "\n    expected:   " << coeffExpected[i]
+            << "\n    tolerance:  " << tol);
+        }
+    }    
+
+    // an alternative container type 
+    boost::circular_buffer<Real> cx(x.begin(), x.end()), cy(y.begin(), y.end());
+    LinearRegression m1(cx, cy);
+
+    for (Size i=0; i < m1.dim(); ++i) {
+        if (std::fabs(m1.standardErrors()[i]-errorsExpected[i]) > tol) {
+            BOOST_ERROR("Failed to reproduce linear regression standard errors"
+                << "\n    calculated: " << m1.standardErrors()[i]
+            << "\n    expected:   " << errorsExpected[i]                                          
+            << "\n    tolerance:  " << tol);
+        }
+
+        if (std::fabs(m1.coefficients()[i]-coeffExpected[i]) > tol) {
+            BOOST_ERROR("Failed to reproduce linear regression coef."
+                << "\n    calculated: " << m1.coefficients()[i]
+            << "\n    expected:   " << coeffExpected[i]
+            << "\n    tolerance:  " << tol);
         }
     }    
 }
