@@ -155,7 +155,7 @@ void MCLongstaffSchwartzEngineTest::testAmericanOption() {
     LsmBasisSystem::PolynomType polynomTypes[]
         = { LsmBasisSystem::Monomial, LsmBasisSystem::Laguerre,
             LsmBasisSystem::Hermite, LsmBasisSystem::Hyperbolic,
-            LsmBasisSystem::Chebyshev2th };
+            LsmBasisSystem::Chebyshev2nd };
 
     for (Integer i=0; i<2; ++i) {
         for (Integer j=0; j<3; ++j) {
@@ -181,7 +181,7 @@ void MCLongstaffSchwartzEngineTest::testAmericanOption() {
                 MakeMCAmericanEngine<PseudoRandom>(stochasticProcess)
                   .withSteps(75)
                   .withAntitheticVariate()
-                  .withTolerance(0.02)
+                  .withAbsoluteTolerance(0.02)
                   .withSeed(42)
                   .withPolynomOrder(3)
                   .withBasisSystem(
@@ -193,7 +193,8 @@ void MCLongstaffSchwartzEngineTest::testAmericanOption() {
             const Real errorEstimate = americanOption.errorEstimate();
 
             americanOption.setPricingEngine(boost::shared_ptr<PricingEngine>(
-                          new FDAmericanEngine(stochasticProcess, 401, 200)));
+                        new FDAmericanEngine<CrankNicolson>(stochasticProcess,
+                                                            401, 200)));
             const Real expected = americanOption.NPV();
 
             if (std::fabs(calculated - expected) > 2.34*errorEstimate) {
@@ -278,7 +279,7 @@ void MCLongstaffSchwartzEngineTest::testAmericanMaxOption() {
     const Real expected[] = {8.08, 13.90, 21.34};
     for (Size i = 0; i < 3; ++i) {
 
-        const Real underlying = 90 + i*10;
+        const Real underlying = 90.0 + i*10.0;
         underlyingH.linkTo(
             boost::shared_ptr<Quote>(new SimpleQuote(underlying)));
 
