@@ -31,34 +31,37 @@
 
  Example results: 1. Core2 Q9300@2.5Ghz  :2272.6 mflops
                   2. Core2 Q6600@2.4Ghz  :1984.0 mflops
-                  3. Core2 Dual@2.0Ghz   : 835.9 mflops
-                  4. Athlon 64 X2 4400+  : 824.2 mflops
-                  5. Core2 Dual@2.0Ghz   : 754.1 mflops
-                  6. Pentium4 Dual@2.8Ghz: 423.8 mflops
-                  7. Pentium4@3.0Ghz     : 266.3 mflops
-                  8. PentiumIII@1.1Ghz   : 146.2 mflops
-                  9. Alpha 2xEV68@833Mhz : 184.6 mflops
-                 10. Strong ARM@206Mhz   :   1.4 mflops
+                  3. i3 540@3.1Ghz       :1755.3 mflops
+                  4. Core2 Dual@2.0Ghz   : 835.9 mflops
+                  5. Athlon 64 X2 4400+  : 824.2 mflops
+                  6. Core2 Dual@2.0Ghz   : 754.1 mflops
+                  7. Pentium4 Dual@2.8Ghz: 423.8 mflops
+                  8. Pentium4@3.0Ghz     : 266.3 mflops
+                  9. PentiumIII@1.1Ghz   : 146.2 mflops
+                 10. Alpha 2xEV68@833Mhz : 184.6 mflops
+                 11. Strong ARM@206Mhz   :   1.4 mflops
 
  Remarks: OS: Linux, static libs
   1. icc-11.0,  -gcc-version=420 -fast -fp-model fast=2 -ipo-jobs2
       Remark: four processes
   2. icc-11.0,  -gcc-version=420 -fast -fp-model fast=2 -ipo-jobs2
       Remark: four processes
-  3. icc-11.0,  -gcc-version=420 -fast -fp-model fast=2 -ipo-jobs2
+  3. gcc-4.4.5, -O3 -ffast-math -mfpmath=sse,387 -msse4.2 -march=core2
+      Remark: four processes
+  4. icc-11.0,  -gcc-version=420 -fast -fp-model fast=2 -ipo-jobs2
       Remark: two processes
-  4. icc-11.0,  -gcc-version=420 -xSSSE3 -O3 -ipo -no-prec-div -static
+  5. icc-11.0,  -gcc-version=420 -xSSSE3 -O3 -ipo -no-prec-div -static
                 -fp-model fast=2 -ipo-jobs2, Remark: two processes
-  5. gcc-4.2.1, -O3 -ffast-math -mfpmath=sse,387 -msse3 -funroll-all-loops
+  6. gcc-4.2.1, -O3 -ffast-math -mfpmath=sse,387 -msse3 -funroll-all-loops
       Remark: two processes
-  6. gcc-4.0.1, -O3 -march=pentium4 -ffast-math
-      -mfpmath=sse,387 -msse2 -funroll-all-loops, Remark: two processes
   7. gcc-4.0.1, -O3 -march=pentium4 -ffast-math
+      -mfpmath=sse,387 -msse2 -funroll-all-loops, Remark: two processes
+  8. gcc-4.0.1, -O3 -march=pentium4 -ffast-math
                 -mfpmath=sse,387 -msse2 -funroll-all-loops
-  8. gcc-4.1.1, -O3 -march=pentium3 -ffast-math
+  9. gcc-4.1.1, -O3 -march=pentium3 -ffast-math
                 -mfpmath=sse,387 -msse -funroll-all-loops
-  9. gcc-3.3.5, -O3 -mcpu=e67 -funroll-all-loops, Remark: two processes
- 10. gcc-3.4.3, -O2 -g on a Zaurus PDA
+ 10. gcc-3.3.5, -O3 -mcpu=e67 -funroll-all-loops, Remark: two processes
+ 11. gcc-3.4.3, -O2 -g on a Zaurus PDA
 
   This benchmark is derived from quantlibtestsuite.cpp. Please see the
   copyrights therein.
@@ -74,6 +77,7 @@
 #include <string>
 
 /* PAPI code
+#include <stdio.h
 #include <papi.h>
 */
 
@@ -149,7 +153,7 @@ namespace {
 
     /* PAPI code
     float real_time, proc_time, mflops;
-    long_long lflops, flop=0;
+    long_long lflop, flop=0;
     */
 
     void startTimer() {
@@ -237,8 +241,6 @@ test_suite* init_unit_test_suite(int, char*[]) {
         &ConvertibleBondTest::testBond, 159.85));
     bm.push_back(Benchmark("DigitalOption::MCCashAtHit",
         &DigitalOptionTest::testMCCashAtHit,995.87));
-    bm.push_back(Benchmark("DividendOption::FdEuropeanValues",
-        &DividendOptionTest::testFdEuropeanValues, 992.12));
     bm.push_back(Benchmark("DividendOption::FdEuropeanGreeks",
         &DividendOptionTest::testFdEuropeanGreeks, 949.52));
     bm.push_back(Benchmark("DividendOption::FdAmericanGreeks",
@@ -255,8 +257,6 @@ test_suite* init_unit_test_suite(int, char*[]) {
         &FdHestonTest::testFdmHestonAmerican, 234.21));
     bm.push_back(Benchmark("HestonModel::DAXCalibration",
         &HestonModelTest::testDAXCalibration, 555.19));
-    bm.push_back(Benchmark("HestonModel::McVsCached",
-        &HestonModelTest::testMcVsCached, 150.04));
     bm.push_back(Benchmark("InterpolationTest::testSabrInterpolation",
         &InterpolationTest::testSabrInterpolation, 2266.06));
     bm.push_back(Benchmark("JumpDiffusion::Greeks",
