@@ -93,6 +93,8 @@
 #include "inflation.hpp"
 #include "inflationcapfloor.hpp"
 #include "inflationcapflooredcoupon.hpp"
+#include "inflationcpicapfloor.hpp"
+#include "inflationcpiswap.hpp"
 #include "inflationvolatility.hpp"
 #include "instruments.hpp"
 #include "integrals.hpp"
@@ -130,14 +132,18 @@
 #include "rngtraits.hpp"
 #include "rounding.hpp"
 #include "sampledcurve.hpp"
+#include "schedule.hpp"
 #include "shortratemodels.hpp"
 #include "solvers.hpp"
+#include "spreadoption.hpp"
+#include "swingoption.hpp"
 #include "surface.hpp"
 #include "stats.hpp"
 #include "swap.hpp"
 #include "swapforwardmappings.hpp"
 #include "swaption.hpp"
 #include "swaptionvolatilitycube.hpp"
+#include "swaptionvolatilitymatrix.hpp"
 #include "termstructures.hpp"
 #include "timeseries.hpp"
 #include "tqreigendecomposition.hpp"
@@ -147,7 +153,8 @@
 #include "varianceoption.hpp"
 #include "varianceswaps.hpp"
 #include "volatilitymodels.hpp"
-#include "swaptionvolatilitymatrix.hpp"
+#include "vpp.hpp"
+#include "writerextensibleoption.hpp"
 
 #include <iostream>
 #include <iomanip>
@@ -198,17 +205,39 @@ namespace QuantLib {
 
 test_suite* init_unit_test_suite(int, char* []) {
 
-    std::string header = "Testing "
-                         #ifdef BOOST_MSVC
-                         QL_LIB_NAME
-                         #else
-                         "QuantLib " QL_VERSION
-                         #endif
-                         #ifdef QL_DISABLE_DEPRECATED
-                         " (deprecated code disabled)"
-                         #endif
-                         ;
-    std::string rule = std::string(header.length(),'=');
+    std::string header =
+        " Testing "
+            #ifdef BOOST_MSVC
+            QL_LIB_NAME
+            #else
+            "QuantLib " QL_VERSION
+            #endif
+        "\n  QL_NEGATIVE_RATES "
+            #ifdef QL_NEGATIVE_RATES
+            "       defined"
+            #else
+            "     undefined"
+            #endif
+        "\n  QL_EXTRA_SAFETY_CHECKS "
+            #ifdef QL_EXTRA_SAFETY_CHECKS
+            "  defined"
+            #else
+            "undefined"
+            #endif
+        "\n  QL_DISABLE_DEPRECATED "
+            #ifdef QL_DISABLE_DEPRECATED
+            "   defined"
+            #else
+            " undefined"
+            #endif
+        "\n  QL_USE_INDEXED_COUPON "
+            #ifdef QL_USE_INDEXED_COUPON
+            "   defined"
+            #else
+            " undefined"
+            #endif
+         ;
+    std::string rule = std::string(35, '=');
 
     BOOST_MESSAGE(rule);
     BOOST_MESSAGE(header);
@@ -269,6 +298,8 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(InflationTest::suite());                  // in general inflation & tests
     test->add(InflationCapFloorTest::suite());          // use indexed coupons, i.e.
     test->add(InflationCapFlooredCouponTest::suite());  // QL_USE_INDEXED_COUPON has no effect
+    test->add(CPISwapTest::suite());                    //
+    test->add(InflationCPICapFloorTest::suite());       //
     test->add(InflationVolTest::suite());               //
     test->add(InstrumentTest::suite());
     test->add(IntegralTest::suite());
@@ -304,8 +335,11 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(RngTraitsTest::suite());
     test->add(RoundingTest::suite());
     test->add(SampledCurveTest::suite());
+    test->add(ScheduleTest::suite());
     test->add(ShortRateModelTest::suite()); // fails with QL_USE_INDEXED_COUPON
     test->add(Solver1DTest::suite());
+    test->add(SpreadOptionTest::suite());
+    test->add(SwingOptionTest::suite());
     test->add(StatisticsTest::suite());
     test->add(SurfaceTest::suite());
     test->add(SwapTest::suite());
@@ -322,6 +356,8 @@ test_suite* init_unit_test_suite(int, char* []) {
     test->add(VarianceOptionTest::suite());
     test->add(VarianceSwapTest::suite());
     test->add(VolatilityModelsTest::suite());
+    test->add(VPPTest::suite());
+    test->add(WriterExtensibleOptionTest::suite());
 
     //tests for deprecated classes
     test->add(LiborMarketModelTest::suite());
