@@ -60,7 +60,7 @@ namespace {
         const std::vector<Volatility>& volatilities(){return volatilities_;}
         const std::vector<Rate>& displacements(){return displacements_;}
         const std::vector<DiscountFactor>& discountFactors(){return discountFactors_;}
-        const Size nbRates(){return nbRates_;}
+        Size nbRates() {return nbRates_;}
     private:
         std::vector<Time> rateTimes_, accruals_;
         std::vector<Rate> forwards_;
@@ -237,7 +237,7 @@ void SwapForwardMappingsTest::testForwardSwapJacobians()
 
     {
 
-        BOOST_MESSAGE("Testing forward-rate cm-swap Jacobian...");
+        BOOST_MESSAGE("Testing forward-rate constant-maturity swap Jacobian...");
         MarketModelData marketData;
         const std::vector<Time>& rateTimes = marketData.rateTimes();
         const std::vector<Rate>& forwards = marketData.forwards();
@@ -371,7 +371,7 @@ void SwapForwardMappingsTest::testForwardCoterminalMappings() {
 void SwapForwardMappingsTest::testSwaptionImpliedVolatility() 
 {
 
-    BOOST_MESSAGE("Testing swaption implied vol in LMM using HW approximation...");
+    BOOST_MESSAGE("Testing implied swaption vol in LMM using HW approximation...");
     MarketModelData marketData;
     const std::vector<Time>& rateTimes = marketData.rateTimes();
     const std::vector<Rate>& forwards = marketData.forwards();
