@@ -24,11 +24,12 @@
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
 
-QL_BEGIN_TEST_LOCALS(TqrEigenDecompositionTest)
+namespace {
 
-Real tolerance = 1.0e-10;
+    Real tolerance = 1.0e-10;
+
+}
 
-QL_END_TEST_LOCALS(TqrEigenDecompositionTest)
 
 void TqrEigenDecompositionTest::testEigenValueDecomposition() {
     BOOST_MESSAGE("Testing TQR eigenvalue decomposition...");
@@ -101,11 +102,11 @@ void TqrEigenDecompositionTest::testEigenVectorDecomposition() {
 
 test_suite* TqrEigenDecompositionTest::suite() {
     test_suite* suite = BOOST_TEST_SUITE("TQR eigendecomposition tests");
-    suite->add(BOOST_TEST_CASE(
+    suite->add(QUANTLIB_TEST_CASE(
                    &TqrEigenDecompositionTest::testEigenValueDecomposition));
-    suite->add(BOOST_TEST_CASE(
+    suite->add(QUANTLIB_TEST_CASE(
                    &TqrEigenDecompositionTest::testZeroOffDiagEigenValues));
-    suite->add(BOOST_TEST_CASE(
+    suite->add(QUANTLIB_TEST_CASE(
                    &TqrEigenDecompositionTest::testEigenVectorDecomposition));
     return suite;
 }
