@@ -19,8 +19,9 @@
 
 #include "utilities.hpp"
 #include <ql/instruments/payoffs.hpp>
-#include <ql/termstructures/yieldcurves/flatforward.hpp>
-#include <ql/termstructures/volatilities/blackconstantvol.hpp>
+#include <ql/indexes/indexmanager.hpp>
+#include <ql/termstructures/yield/flatforward.hpp>
+#include <ql/termstructures/volatility/equityfx/blackconstantvol.hpp>
 #include <ql/time/calendars/nullcalendar.hpp>
 
 #define CHECK_DOWNCAST(Derived,Description) { \
@@ -85,22 +86,23 @@ namespace QuantLib {
     flatVol(const Date& today,
             const boost::shared_ptr<Quote>& vol,
             const DayCounter& dc) {
-        return boost::shared_ptr<BlackVolTermStructure>(
-                      new BlackConstantVol(today, Handle<Quote>(vol), dc));
+        return boost::shared_ptr<BlackVolTermStructure>(new
+            BlackConstantVol(today, NullCalendar(), Handle<Quote>(vol), dc));
     }
 
     boost::shared_ptr<BlackVolTermStructure>
     flatVol(const Date& today, Volatility vol,
             const DayCounter& dc) {
-        return flatVol(today, boost::shared_ptr<Quote>(new SimpleQuote(vol)),
+        return flatVol(today,
+                       boost::shared_ptr<Quote>(new SimpleQuote(vol)),
                        dc);
     }
 
     boost::shared_ptr<BlackVolTermStructure>
     flatVol(const boost::shared_ptr<Quote>& vol,
             const DayCounter& dc) {
-        return boost::shared_ptr<BlackVolTermStructure>(
-             new BlackConstantVol(0, NullCalendar(), Handle<Quote>(vol), dc));
+        return boost::shared_ptr<BlackVolTermStructure>(new
+            BlackConstantVol(0, NullCalendar(), Handle<Quote>(vol), dc));
     }
 
     boost::shared_ptr<BlackVolTermStructure>
@@ -118,4 +120,11 @@ namespace QuantLib {
             return std::fabs(x1-x2);
     }
 
+
+    IndexHistoryCleaner::IndexHistoryCleaner() {}
+
+    IndexHistoryCleaner::~IndexHistoryCleaner() {
+        IndexManager::instance().clearHistories();
+    }
+
 }
